[goffice] Compilation: grand renaming.



commit 3871aee6eb23067b17d5e0af3d30b5f109d4c47e
Author: Morten Welinder <terra gnome org>
Date:   Wed Aug 19 19:43:20 2009 -0400

    Compilation: grand renaming.

 NEWS                                       |    3 +
 docs/reference/tmpl/gog-object.sgml        |   22 ++--
 docs/reference/tmpl/gog-styled-object.sgml |    8 +
 goffice/app/error-info.c                   |   84 +++++-----
 goffice/app/error-info.h                   |   28 ++--
 goffice/app/file.c                         |    8 +-
 goffice/app/go-cmd-context-impl.h          |    2 +-
 goffice/app/go-cmd-context.c               |    2 +-
 goffice/app/go-cmd-context.h               |    2 +-
 goffice/app/go-plugin-loader-module.c      |   66 ++++----
 goffice/app/go-plugin-loader.c             |   26 ++--
 goffice/app/go-plugin-loader.h             |   32 ++--
 goffice/app/go-plugin-service-impl.h       |    6 +-
 goffice/app/go-plugin-service.c            |   92 ++++++------
 goffice/app/go-plugin-service.h            |   18 +-
 goffice/app/go-plugin.c                    |  240 ++++++++++++++--------------
 goffice/app/go-plugin.h                    |   14 +-
 goffice/app/goffice-app.h                  |    2 +-
 goffice/app/io-context-priv.h              |    2 +-
 goffice/app/io-context.c                   |   26 ++--
 goffice/app/io-context.h                   |    4 +-
 goffice/component/go-component-factory.c   |    8 +-
 goffice/graph/gog-plot-engine.c            |   26 ++--
 goffice/utils/datetime.c                   |   12 +-
 goffice/utils/datetime.h                   |    4 +-
 25 files changed, 374 insertions(+), 363 deletions(-)
---
diff --git a/NEWS b/NEWS
index 27e8206..c2fb811 100644
--- a/NEWS
+++ b/NEWS
@@ -1,5 +1,8 @@
 goffice 0.7.10:
 
+Morten:
+	* Namespace issues.  [#592283]
+
 --------------------------------------------------------------------------
 goffice 0.7.9:
 
diff --git a/docs/reference/tmpl/gog-object.sgml b/docs/reference/tmpl/gog-object.sgml
index 69a0b86..dc3cd3e 100644
--- a/docs/reference/tmpl/gog-object.sgml
+++ b/docs/reference/tmpl/gog-object.sgml
@@ -54,53 +54,53 @@ Base class for all objects of graph model
 
 </para>
 
- gogobject: the object which received the signal.
- arg1: 
+@: 
+@: 
 
 <!-- ##### SIGNAL GogObject::child-added ##### -->
 <para>
 
 </para>
 
- gogobject: the object which received the signal.
- arg1: 
+@: 
+@: 
 
 <!-- ##### SIGNAL GogObject::child-name-changed ##### -->
 <para>
 
 </para>
 
- gogobject: the object which received the signal.
- arg1: 
+@: 
+@: 
 
 <!-- ##### SIGNAL GogObject::child-removed ##### -->
 <para>
 
 </para>
 
- gogobject: the object which received the signal.
- arg1: 
+@: 
+@: 
 
 <!-- ##### SIGNAL GogObject::children-reordered ##### -->
 <para>
 
 </para>
 
- gogobject: the object which received the signal.
+@: 
 
 <!-- ##### SIGNAL GogObject::name-changed ##### -->
 <para>
 
 </para>
 
- gogobject: the object which received the signal.
+@: 
 
 <!-- ##### SIGNAL GogObject::update-editor ##### -->
 <para>
 
 </para>
 
- gogobject: the object which received the signal.
+@: 
 
 <!-- ##### ARG GogObject:alignment ##### -->
 <para>
diff --git a/docs/reference/tmpl/gog-styled-object.sgml b/docs/reference/tmpl/gog-styled-object.sgml
index e9fe2e6..b6b959a 100644
--- a/docs/reference/tmpl/gog-styled-object.sgml
+++ b/docs/reference/tmpl/gog-styled-object.sgml
@@ -37,3 +37,11 @@ functionnalities used for drawing object on graph canvas.
 
 </para>
 
+<!-- ##### FUNCTION gog_style_new ##### -->
+<para>
+
+</para>
+
+ Returns: 
+
+
diff --git a/goffice/app/error-info.h b/goffice/app/error-info.h
index 280ca1a..24e9172 100644
--- a/goffice/app/error-info.h
+++ b/goffice/app/error-info.h
@@ -11,22 +11,22 @@ typedef enum {
 	GO_ERROR
 } GOSeverity;
 
-ErrorInfo *error_info_new_str			(char const *msg);
-ErrorInfo *error_info_new_printf		(char const *msg_format, ...) G_GNUC_PRINTF (1, 2);
-ErrorInfo *error_info_new_vprintf		(GOSeverity severity,
+GOErrorInfo *go_error_info_new_str			(char const *msg);
+GOErrorInfo *go_error_info_new_printf		(char const *msg_format, ...) G_GNUC_PRINTF (1, 2);
+GOErrorInfo *go_error_info_new_vprintf		(GOSeverity severity,
 						 char const *msg_format,
 						 va_list args);
-ErrorInfo *error_info_new_str_with_details	(char const *msg, ErrorInfo *details);
-ErrorInfo *error_info_new_str_with_details_list (char const *msg, GSList *details);
-ErrorInfo *error_info_new_from_error_list	(GSList *errors);
-ErrorInfo *error_info_new_from_errno		(void);
-void	   error_info_add_details		(ErrorInfo *error, ErrorInfo *details);
-void	   error_info_add_details_list	  	(ErrorInfo *error, GSList *details);
-void	   error_info_free			(ErrorInfo *error);
-void	   error_info_print			(ErrorInfo *error);
-char const*error_info_peek_message		(ErrorInfo *error);
-GSList	  *error_info_peek_details		(ErrorInfo *error);
-GOSeverity error_info_peek_severity		(ErrorInfo *error);
+GOErrorInfo *go_error_info_new_str_with_details	(char const *msg, GOErrorInfo *details);
+GOErrorInfo *go_error_info_new_str_with_details_list (char const *msg, GSList *details);
+GOErrorInfo *go_error_info_new_from_error_list	(GSList *errors);
+GOErrorInfo *go_error_info_new_from_errno		(void);
+void	   go_error_info_add_details		(GOErrorInfo *error, GOErrorInfo *details);
+void	   go_error_info_add_details_list	  	(GOErrorInfo *error, GSList *details);
+void	   go_error_info_free			(GOErrorInfo *error);
+void	   go_error_info_print			(GOErrorInfo *error);
+char const*go_error_info_peek_message		(GOErrorInfo *error);
+GSList	  *go_error_info_peek_details		(GOErrorInfo *error);
+GOSeverity go_error_info_peek_severity		(GOErrorInfo *error);
 
 #define GO_INIT_RET_ERROR_INFO(ret_error) \
 G_STMT_START { \
diff --git a/goffice/app/file.c b/goffice/app/file.c
index b71a167..cd05f6d 100644
--- a/goffice/app/file.c
+++ b/goffice/app/file.c
@@ -683,7 +683,7 @@ go_file_saver_save (GOFileSaver const *fs, IOContext *io_context,
 		if (!fs->overwrite_files &&
 		    file_name &&
 		    g_file_test (file_name, G_FILE_TEST_EXISTS)) {
-			ErrorInfo *save_error;
+			GOErrorInfo *save_error;
 			const char *msg = _("Saving over old files of this type is disabled for safety.");
 
 			if (!gsf_output_error (output))
@@ -691,11 +691,11 @@ go_file_saver_save (GOFileSaver const *fs, IOContext *io_context,
 
 			g_free (file_name);
 
-			save_error = error_info_new_str_with_details (
+			save_error = go_error_info_new_str_with_details (
 				msg,
-				error_info_new_str (
+				go_error_info_new_str (
 					_("You can turn this safety feature off by editing appropriate plugin.xml file.")));
-			gnumeric_io_error_info_set (io_context, save_error);
+			gnumeric_io_go_error_info_set (io_context, save_error);
 			return;
 		}
 
diff --git a/goffice/app/go-cmd-context-impl.h b/goffice/app/go-cmd-context-impl.h
index e31c315..683d28e 100644
--- a/goffice/app/go-cmd-context-impl.h
+++ b/goffice/app/go-cmd-context-impl.h
@@ -14,7 +14,7 @@ typedef struct {
 					 gboolean sensitive);
 	struct {
 		void (*error)		(GOCmdContext *gcc, GError *err);
-		void (*error_info)  	(GOCmdContext *gcc, ErrorInfo *err);
+		void (*error_info)  	(GOCmdContext *gcc, GOErrorInfo *err);
 	} error;
 
 	void    (*progress_set)		(GOCmdContext *gcc, float val);
diff --git a/goffice/app/go-cmd-context.c b/goffice/app/go-cmd-context.c
index 91b6d37..102b67f 100644
--- a/goffice/app/go-cmd-context.c
+++ b/goffice/app/go-cmd-context.c
@@ -29,7 +29,7 @@ go_cmd_context_error (GOCmdContext *context, GError *err)
 }
 
 void
-go_cmd_context_error_info (GOCmdContext *context, ErrorInfo *stack)
+go_cmd_context_error_info (GOCmdContext *context, GOErrorInfo *stack)
 {
 	g_return_if_fail (GO_IS_CMD_CONTEXT (context));
 	GCC_CLASS (context)->error.error_info (context, stack);
diff --git a/goffice/app/go-cmd-context.h b/goffice/app/go-cmd-context.h
index c38222f..0b6e08b 100644
--- a/goffice/app/go-cmd-context.h
+++ b/goffice/app/go-cmd-context.h
@@ -42,7 +42,7 @@ void   go_cmd_context_error_import  (GOCmdContext *cc, char const *msg);
 void   go_cmd_context_error_export  (GOCmdContext *cc, char const *msg);
 void   go_cmd_context_error_invalid (GOCmdContext *cc,
 				     char const *msg, char const *val);
-void   go_cmd_context_error_info    (GOCmdContext *cc, ErrorInfo *stack);
+void   go_cmd_context_error_info    (GOCmdContext *cc, GOErrorInfo *stack);
 
 /* An initial set of std errors */
 GQuark go_error_system  (void);
diff --git a/goffice/app/go-plugin-loader-module.c b/goffice/app/go-plugin-loader-module.c
index 151dabf..d513b16 100644
--- a/goffice/app/go-plugin-loader-module.c
+++ b/goffice/app/go-plugin-loader-module.c
@@ -23,13 +23,13 @@
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
-static void go_plugin_loader_module_set_attributes (GOPluginLoader *loader, GHashTable *attrs, ErrorInfo **ret_error);
-static void go_plugin_loader_module_load_base (GOPluginLoader *loader, ErrorInfo **ret_error);
-static void go_plugin_loader_module_unload_base (GOPluginLoader *loader, ErrorInfo **ret_error);
+static void go_plugin_loader_module_set_attributes (GOPluginLoader *loader, GHashTable *attrs, GOErrorInfo **ret_error);
+static void go_plugin_loader_module_load_base (GOPluginLoader *loader, GOErrorInfo **ret_error);
+static void go_plugin_loader_module_unload_base (GOPluginLoader *loader, GOErrorInfo **ret_error);
 
-static void go_plugin_loader_module_load_service_file_opener (GOPluginLoader *loader, GOPluginService *service, ErrorInfo **ret_error);
-static void go_plugin_loader_module_load_service_file_saver (GOPluginLoader *loader, GOPluginService *service, ErrorInfo **ret_error);
-static void go_plugin_loader_module_load_service_plugin_loader (GOPluginLoader *loader, GOPluginService *service, ErrorInfo **ret_error);
+static void go_plugin_loader_module_load_service_file_opener (GOPluginLoader *loader, GOPluginService *service, GOErrorInfo **ret_error);
+static void go_plugin_loader_module_load_service_file_saver (GOPluginLoader *loader, GOPluginService *service, GOErrorInfo **ret_error);
+static void go_plugin_loader_module_load_service_plugin_loader (GOPluginLoader *loader, GOPluginService *service, GOErrorInfo **ret_error);
 
 static GHashTable *go_plugin_loader_module_known_deps = NULL;
 
@@ -45,7 +45,7 @@ go_plugin_loader_module_register_version (char const *id, char const *version)
 
 static void
 go_plugin_loader_module_set_attributes (GOPluginLoader *loader, GHashTable *attrs,
-					ErrorInfo **err)
+					GOErrorInfo **err)
 {
 	GOPluginLoaderModule *loader_module = GO_PLUGIN_LOADER_MODULE (loader);
 	gchar *module_file_name = g_hash_table_lookup (attrs, "module_file");
@@ -53,17 +53,17 @@ go_plugin_loader_module_set_attributes (GOPluginLoader *loader, GHashTable *attr
 	if (module_file_name != NULL)
 		loader_module->module_file_name = g_strdup (module_file_name);
 	else
-		*err = error_info_new_str ( _("Module file name not given."));
+		*err = go_error_info_new_str ( _("Module file name not given."));
 }
 
-static ErrorInfo *
+static GOErrorInfo *
 check_version (GOPluginModuleDepend const *deps, guint32 num_deps, char const *module_file)
 {
 	unsigned i;
 	char const *ver;
 
 	if (deps == NULL && num_deps != 0)
-		return error_info_new_printf (
+		return go_error_info_new_printf (
 			_("Module \"%s\" has an inconsistent dependency list."),
 			module_file);
 
@@ -71,17 +71,17 @@ check_version (GOPluginModuleDepend const *deps, guint32 num_deps, char const *m
 
 	for (i = 0; i < num_deps ; i++) {
 		if (deps[i].key == NULL)
-			return error_info_new_printf (
+			return go_error_info_new_printf (
 				_("Module \"%s\" depends on an invalid null dependency."),
 				module_file);
 		ver = g_hash_table_lookup (go_plugin_loader_module_known_deps, deps[i].key);
 		if (ver == NULL)
-			return error_info_new_printf (
+			return go_error_info_new_printf (
 				_("Module \"%s\" depends on an unknown dependency '%s'."),
 				module_file, deps[i].key);
 
 		if (strcmp (ver, deps[i].version))
-			return error_info_new_printf (
+			return go_error_info_new_printf (
 				_("Module \"%s\" was built with version %s of %s, but this executable supplied version %s."),
 				module_file, deps[i].version, deps[i].key, ver);
 	}
@@ -89,7 +89,7 @@ check_version (GOPluginModuleDepend const *deps, guint32 num_deps, char const *m
 }
 
 static void
-go_plugin_loader_module_load_base (GOPluginLoader *loader, ErrorInfo **err)
+go_plugin_loader_module_load_base (GOPluginLoader *loader, GOErrorInfo **err)
 {
 	GOPluginLoaderModule *loader_module = GO_PLUGIN_LOADER_MODULE (loader);
 	gchar *full_module_file_name;
@@ -99,7 +99,7 @@ go_plugin_loader_module_load_base (GOPluginLoader *loader, ErrorInfo **err)
 
 	GO_INIT_RET_ERROR_INFO (err);
 	if (!g_module_supported ()) {
-		*err = error_info_new_str (
+		*err = go_error_info_new_str (
 			_("Dynamic module loading is not supported in this system."));
 		return;
 	}
@@ -109,19 +109,19 @@ go_plugin_loader_module_load_base (GOPluginLoader *loader, ErrorInfo **err)
 		loader_module->module_file_name, NULL);
 	handle = g_module_open (full_module_file_name, G_MODULE_BIND_LAZY);
 	if (handle == NULL) {
-		*err = error_info_new_printf (
+		*err = go_error_info_new_printf (
 			_("Unable to open module file \"%s\"."),
 			full_module_file_name);
-		error_info_add_details (*err, error_info_new_str (g_module_error()));
+		go_error_info_add_details (*err, go_error_info_new_str (g_module_error()));
 	} else {
 		g_module_symbol (handle, "go_plugin_header", (gpointer) &go_plugin_header);
 		g_module_symbol (handle, "go_plugin_depends", (gpointer) &go_plugin_depends);
 		if (go_plugin_header == NULL) {
-			*err = error_info_new_printf (
+			*err = go_error_info_new_printf (
 				_("Module \"%s\" doesn't contain (\"go_plugin_header\" symbol)."),
 				full_module_file_name);
 		} else if (go_plugin_header->magic_number != GOFFICE_MODULE_PLUGIN_MAGIC_NUMBER) {
-			*err = error_info_new_printf (
+			*err = go_error_info_new_printf (
 				_("Module \"%s\" has an invalid magic number."),
 				full_module_file_name);
 		} else if (NULL == (*err = check_version (go_plugin_depends,  go_plugin_header->num_depends, full_module_file_name))) {
@@ -139,7 +139,7 @@ go_plugin_loader_module_load_base (GOPluginLoader *loader, ErrorInfo **err)
 }
 
 static void
-go_plugin_loader_module_unload_base (GOPluginLoader *loader, ErrorInfo **ret_error)
+go_plugin_loader_module_unload_base (GOPluginLoader *loader, GOErrorInfo **ret_error)
 {
 	GOPluginLoaderModule *loader_module = GO_PLUGIN_LOADER_MODULE (loader);
 
@@ -148,10 +148,10 @@ go_plugin_loader_module_unload_base (GOPluginLoader *loader, ErrorInfo **ret_err
 		loader_module->plugin_shutdown (go_plugin_loader_get_plugin (loader), NULL);
 	}
 	if (!g_module_close (loader_module->handle)) {
-		*ret_error = error_info_new_printf (
+		*ret_error = go_error_info_new_printf (
 			_("Unable to close module file \"%s\"."),
 			loader_module->module_file_name);
-		error_info_add_details (*ret_error, error_info_new_str (g_module_error()));
+		go_error_info_add_details (*ret_error, go_error_info_new_str (g_module_error()));
 	}
 	loader_module->handle = NULL;
 	loader_module->plugin_init = NULL;
@@ -261,7 +261,7 @@ make_function_name (const GOPluginService *service, const char *suffix)
 static void
 go_plugin_loader_module_load_service_file_opener (GOPluginLoader *loader,
 						  GOPluginService *service,
-						  ErrorInfo **ret_error)
+						  GOErrorInfo **ret_error)
 {
 	GOPluginLoaderModule *loader_module = GO_PLUGIN_LOADER_MODULE (loader);
 	gchar *func_name_file_probe, *func_name_file_open;
@@ -288,10 +288,10 @@ go_plugin_loader_module_load_service_file_opener (GOPluginLoader *loader,
 		g_object_set_data_full (G_OBJECT (service),
 					"loader_data", loader_data, g_free);
 	} else {
-		*ret_error = error_info_new_printf (
+		*ret_error = go_error_info_new_printf (
 			_("Module file \"%s\" has invalid format."),
 			loader_module->module_file_name);
-		error_info_add_details (*ret_error, error_info_new_printf (
+		go_error_info_add_details (*ret_error, go_error_info_new_printf (
 			_("File doesn't contain \"%s\" function."), func_name_file_open));
 	}
 	g_free (func_name_file_probe);
@@ -327,7 +327,7 @@ go_plugin_loader_module_func_file_save (GOFileSaver const *fs, GOPluginService *
 static void
 go_plugin_loader_module_load_service_file_saver (GOPluginLoader *loader,
 						 GOPluginService *service,
-						 ErrorInfo **ret_error)
+						 GOErrorInfo **ret_error)
 {
 	GOPluginLoaderModule *loader_module = GO_PLUGIN_LOADER_MODULE (loader);
 	gchar *func_name_file_save;
@@ -350,10 +350,10 @@ go_plugin_loader_module_load_service_file_saver (GOPluginLoader *loader,
 		g_object_set_data_full (G_OBJECT (service),
 					"loader_data", loader_data, g_free);
 	} else {
-		*ret_error = error_info_new_printf (
+		*ret_error = go_error_info_new_printf (
 			_("Module file \"%s\" has invalid format."),
 			loader_module->module_file_name);
-		error_info_add_details (*ret_error, error_info_new_printf (
+		go_error_info_add_details (*ret_error, go_error_info_new_printf (
 			_("File doesn't contain \"%s\" function."),
 			func_name_file_save));
 	}
@@ -365,15 +365,15 @@ go_plugin_loader_module_load_service_file_saver (GOPluginLoader *loader,
  */
 
 typedef struct {
-	GType (*module_func_get_loader_type) (ErrorInfo **ret_error);
+	GType (*module_func_get_loader_type) (GOErrorInfo **ret_error);
 } ServiceLoaderDataPluginLoader;
 
 static GType
 go_plugin_loader_module_func_get_loader_type (GOPluginService *service,
-					       ErrorInfo **ret_error)
+					       GOErrorInfo **ret_error)
 {
 	ServiceLoaderDataPluginLoader *loader_data;
-	ErrorInfo *error = NULL;
+	GOErrorInfo *error = NULL;
 	GType loader_type;
 
 	g_return_val_if_fail (GO_IS_PLUGIN_SERVICE_PLUGIN_LOADER (service), 0);
@@ -392,7 +392,7 @@ go_plugin_loader_module_func_get_loader_type (GOPluginService *service,
 static void
 go_plugin_loader_module_load_service_plugin_loader (GOPluginLoader *loader,
 						    GOPluginService *service,
-						    ErrorInfo **ret_error)
+						    GOErrorInfo **ret_error)
 {
 	GOPluginLoaderModule *loader_module = GO_PLUGIN_LOADER_MODULE (loader);
 	gchar *func_name_get_loader_type;
@@ -417,7 +417,7 @@ go_plugin_loader_module_load_service_plugin_loader (GOPluginLoader *loader,
 		g_object_set_data_full (G_OBJECT (service),
 					"loader_data", loader_data, g_free);
 	} else
-		*ret_error = error_info_new_printf (
+		*ret_error = go_error_info_new_printf (
 			_("Module doesn't contain \"%s\" function."),
 			func_name_get_loader_type);
 	g_free (func_name_get_loader_type);
diff --git a/goffice/app/go-plugin-loader.c b/goffice/app/go-plugin-loader.c
index 041b56b..ad887d0 100644
--- a/goffice/app/go-plugin-loader.c
+++ b/goffice/app/go-plugin-loader.c
@@ -36,7 +36,7 @@ go_plugin_loader_set_plugin (GOPluginLoader *l, GOPlugin *p)
 
 void
 go_plugin_loader_set_attributes (GOPluginLoader *loader, GHashTable *attrs,
-				 ErrorInfo **err)
+				 GOErrorInfo **err)
 {
 	g_return_if_fail (GO_IS_PLUGIN_LOADER (loader));
 
@@ -44,11 +44,11 @@ go_plugin_loader_set_attributes (GOPluginLoader *loader, GHashTable *attrs,
 	if (PL_GET_CLASS (loader)->set_attributes)
 		PL_GET_CLASS (loader)->set_attributes (loader, attrs, err);
 	else
-		*err = error_info_new_printf (_("Loader has no set_attributes method.\n"));
+		*err = go_error_info_new_printf (_("Loader has no set_attributes method.\n"));
 }
 
 void
-go_plugin_loader_load_base (GOPluginLoader *loader, ErrorInfo **err)
+go_plugin_loader_load_base (GOPluginLoader *loader, GOErrorInfo **err)
 {
 	GOPluginLoaderClass *go_plugin_loader_class;
 
@@ -59,13 +59,13 @@ go_plugin_loader_load_base (GOPluginLoader *loader, ErrorInfo **err)
 	if (go_plugin_loader_class->load_base != NULL)
 		go_plugin_loader_class->load_base (loader, err);
 	else
-		*err = error_info_new_printf (_("Loader has no load_base method.\n"));
+		*err = go_error_info_new_printf (_("Loader has no load_base method.\n"));
 	if (*err == NULL)
 		g_object_set_data (G_OBJECT (loader), "is-base-loaded", GINT_TO_POINTER (1));
 }
 
 void
-go_plugin_loader_unload_base (GOPluginLoader *loader, ErrorInfo **err)
+go_plugin_loader_unload_base (GOPluginLoader *loader, GOErrorInfo **err)
 {
 	GOPluginLoaderClass *go_plugin_loader_class;
 
@@ -80,10 +80,10 @@ go_plugin_loader_unload_base (GOPluginLoader *loader, ErrorInfo **err)
 }
 
 void
-go_plugin_loader_load_service (GOPluginLoader *l, GOPluginService *s, ErrorInfo **err)
+go_plugin_loader_load_service (GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err)
 {
 	GOPluginLoaderClass *klass;
-	void (*load_service_method) (GOPluginLoader *, GOPluginService *, ErrorInfo **) = NULL;
+	void (*load_service_method) (GOPluginLoader *, GOPluginService *, GOErrorInfo **) = NULL;
 
 	g_return_if_fail (GO_IS_PLUGIN_LOADER (l));
 	g_return_if_fail (GO_IS_PLUGIN_SERVICE (s));
@@ -104,7 +104,7 @@ go_plugin_loader_load_service (GOPluginLoader *l, GOPluginService *s, ErrorInfo
 	} else if (GO_IS_PLUGIN_SERVICE_SIMPLE (s)) {
 		load_service_method = NULL;
 	} else {
-		*err = error_info_new_printf (_("Service '%s' not supported by l."),
+		*err = go_error_info_new_printf (_("Service '%s' not supported by l."),
 			G_OBJECT_TYPE_NAME (s));
 	}
 	if (load_service_method != NULL)
@@ -118,11 +118,11 @@ go_plugin_loader_load_service (GOPluginLoader *l, GOPluginService *s, ErrorInfo
 }
 
 void
-go_plugin_loader_unload_service (GOPluginLoader *l, GOPluginService *s, ErrorInfo **err)
+go_plugin_loader_unload_service (GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err)
 {
 	GOPluginLoaderClass *klass;
-	void (*unload_service_method) (GOPluginLoader *, GOPluginService *, ErrorInfo **) = NULL;
-	ErrorInfo *error = NULL;
+	void (*unload_service_method) (GOPluginLoader *, GOPluginService *, GOErrorInfo **) = NULL;
+	GOErrorInfo *error = NULL;
 
 	g_return_if_fail (GO_IS_PLUGIN_LOADER (l));
 	g_return_if_fail (GO_IS_PLUGIN_SERVICE (s));
@@ -142,7 +142,7 @@ go_plugin_loader_unload_service (GOPluginLoader *l, GOPluginService *s, ErrorInf
 	} else if (GO_IS_PLUGIN_SERVICE_SIMPLE (s)) {
 		unload_service_method = NULL;
 	} else
-		*err = error_info_new_printf (_("Service '%s' not supported by l."),
+		*err = go_error_info_new_printf (_("Service '%s' not supported by l."),
 			G_OBJECT_TYPE_NAME (s));
 
 	if (unload_service_method != NULL)
@@ -154,7 +154,7 @@ go_plugin_loader_unload_service (GOPluginLoader *l, GOPluginService *s, ErrorInf
 		    GINT_TO_POINTER (GPOINTER_TO_INT (num_services) - 1));;
 		if (GPOINTER_TO_INT (num_services) == 1) {
 			go_plugin_loader_unload_base (l, &error);
-			error_info_free (error);
+			go_error_info_free (error);
 		}
 	} else
 		*err = error;
diff --git a/goffice/app/go-plugin-loader.h b/goffice/app/go-plugin-loader.h
index 7c4ea1c..e5cf776 100644
--- a/goffice/app/go-plugin-loader.h
+++ b/goffice/app/go-plugin-loader.h
@@ -18,31 +18,31 @@ G_BEGIN_DECLS
 typedef struct {
 	GTypeInterface base;
 
-	void (*load_base)		(GOPluginLoader *l, ErrorInfo **err);
-	void (*unload_base)		(GOPluginLoader *l, ErrorInfo **err);
-	void (*set_attributes)		(GOPluginLoader *l, GHashTable *attrs, ErrorInfo **err);
-	gboolean (*service_load)	(GOPluginLoader *l, GOPluginService *s, ErrorInfo **err);
-	gboolean (*service_unload)	(GOPluginLoader *l, GOPluginService *s, ErrorInfo **err);
+	void (*load_base)		(GOPluginLoader *l, GOErrorInfo **err);
+	void (*unload_base)		(GOPluginLoader *l, GOErrorInfo **err);
+	void (*set_attributes)		(GOPluginLoader *l, GHashTable *attrs, GOErrorInfo **err);
+	gboolean (*service_load)	(GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err);
+	gboolean (*service_unload)	(GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err);
 
-	void (*load_service_file_opener)	(GOPluginLoader *l, GOPluginService *s, ErrorInfo **err);
-	void (*unload_service_file_opener)	(GOPluginLoader *l, GOPluginService *s, ErrorInfo **err);
+	void (*load_service_file_opener)	(GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err);
+	void (*unload_service_file_opener)	(GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err);
 
-	void (*load_service_file_saver)		(GOPluginLoader *l, GOPluginService *s, ErrorInfo **err);
-	void (*unload_service_file_saver)	(GOPluginLoader *l, GOPluginService *s, ErrorInfo **err);
+	void (*load_service_file_saver)		(GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err);
+	void (*unload_service_file_saver)	(GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err);
 
-	void (*load_service_plugin_loader)	(GOPluginLoader *l, GOPluginService *s, ErrorInfo **err);
-	void (*unload_service_plugin_loader)	(GOPluginLoader *l, GOPluginService *s, ErrorInfo **err);
+	void (*load_service_plugin_loader)	(GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err);
+	void (*unload_service_plugin_loader)	(GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err);
 } GOPluginLoaderClass;
 
 GType	   go_plugin_loader_get_type (void);
 void	   go_plugin_loader_set_attributes (GOPluginLoader *l, GHashTable *attrs,
-					    ErrorInfo **err);
+					    GOErrorInfo **err);
 GOPlugin *go_plugin_loader_get_plugin	   (GOPluginLoader *l);
 void	   go_plugin_loader_set_plugin	   (GOPluginLoader *l, GOPlugin *p);
-void	   go_plugin_loader_load_base	   (GOPluginLoader *l, ErrorInfo **err);
-void	   go_plugin_loader_unload_base	   (GOPluginLoader *l, ErrorInfo **err);
-void	   go_plugin_loader_load_service   (GOPluginLoader *l, GOPluginService *s, ErrorInfo **err);
-void	   go_plugin_loader_unload_service (GOPluginLoader *l, GOPluginService *s, ErrorInfo **err);
+void	   go_plugin_loader_load_base	   (GOPluginLoader *l, GOErrorInfo **err);
+void	   go_plugin_loader_unload_base	   (GOPluginLoader *l, GOErrorInfo **err);
+void	   go_plugin_loader_load_service   (GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err);
+void	   go_plugin_loader_unload_service (GOPluginLoader *l, GOPluginService *s, GOErrorInfo **err);
 gboolean   go_plugin_loader_is_base_loaded (GOPluginLoader *l);
 
 G_END_DECLS
diff --git a/goffice/app/go-plugin-service-impl.h b/goffice/app/go-plugin-service-impl.h
index ea61bf5..23ea631 100644
--- a/goffice/app/go-plugin-service-impl.h
+++ b/goffice/app/go-plugin-service-impl.h
@@ -47,9 +47,9 @@ struct _GOPluginService {
 typedef struct{
 	GObjectClass g_object_class;
 
-	void (*read_xml) (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error);
-	void (*activate) (GOPluginService *service, ErrorInfo **ret_error);
-	void (*deactivate) (GOPluginService *service, ErrorInfo **ret_error);
+	void (*read_xml) (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error);
+	void (*activate) (GOPluginService *service, GOErrorInfo **ret_error);
+	void (*deactivate) (GOPluginService *service, GOErrorInfo **ret_error);
 	char *(*get_description) (GOPluginService *service);
 } GOPluginServiceClass;
 
diff --git a/goffice/app/go-plugin-service.c b/goffice/app/go-plugin-service.c
index 4dc700d..5a5f864 100644
--- a/goffice/app/go-plugin-service.c
+++ b/goffice/app/go-plugin-service.c
@@ -120,15 +120,15 @@ plugin_service_general_init (GObject *obj)
 }
 
 static void
-plugin_service_general_activate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_general_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	PluginServiceGeneral *service_general = GO_PLUGIN_SERVICE_GENERAL (service);
-	ErrorInfo *error = NULL;
+	GOErrorInfo *error = NULL;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	plugin_service_load (service, &error);
 	if (error != NULL) {
-		*ret_error = error_info_new_str_with_details (
+		*ret_error = go_error_info_new_str_with_details (
 		             _("Error while loading plugin service."),
 		             error);
 		return;
@@ -136,7 +136,7 @@ plugin_service_general_activate (GOPluginService *service, ErrorInfo **ret_error
 	g_return_if_fail (service_general->cbs.plugin_func_init != NULL);
 	service_general->cbs.plugin_func_init (service, &error);
 	if (error != NULL) {
-		*ret_error = error_info_new_str_with_details (
+		*ret_error = go_error_info_new_str_with_details (
 		             _("Initializing function inside plugin returned error."),
 		             error);
 		return;
@@ -145,16 +145,16 @@ plugin_service_general_activate (GOPluginService *service, ErrorInfo **ret_error
 }
 
 static void
-plugin_service_general_deactivate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_general_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	PluginServiceGeneral *service_general = GO_PLUGIN_SERVICE_GENERAL (service);
-	ErrorInfo *error = NULL;
+	GOErrorInfo *error = NULL;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	g_return_if_fail (service_general->cbs.plugin_func_cleanup != NULL);
 	service_general->cbs.plugin_func_cleanup (service, &error);
 	if (error != NULL) {
-		*ret_error = error_info_new_str_with_details (
+		*ret_error = go_error_info_new_str_with_details (
 		             _("Cleanup function inside plugin returned error."),
 		             error);
 		return;
@@ -253,7 +253,7 @@ plugin_service_file_opener_finalize (GObject *obj)
 }
 
 static void
-plugin_service_file_opener_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+plugin_service_file_opener_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	int priority;
 	gboolean has_probe;
@@ -316,12 +316,12 @@ plugin_service_file_opener_read_xml (GOPluginService *service, xmlNode *tree, Er
 		service_file_opener->suffixes	= suffixes;
 		service_file_opener->mimes	= mimes;
 	} else {
-		*ret_error = error_info_new_str (_("File opener has no description"));
+		*ret_error = go_error_info_new_str (_("File opener has no description"));
 	}
 }
 
 static void
-plugin_service_file_opener_activate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_file_opener_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	PluginServiceFileOpener *service_file_opener = GO_PLUGIN_SERVICE_FILE_OPENER (service);
 
@@ -333,7 +333,7 @@ plugin_service_file_opener_activate (GOPluginService *service, ErrorInfo **ret_e
 }
 
 static void
-plugin_service_file_opener_deactivate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_file_opener_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	PluginServiceFileOpener *service_file_opener = GO_PLUGIN_SERVICE_FILE_OPENER (service);
 
@@ -432,12 +432,12 @@ go_plugin_file_opener_probe (GOFileOpener const *fo, GsfInput *input,
 	}
 
 	if (service_file_opener->has_probe) {
-		ErrorInfo *ignored_error = NULL;
+		GOErrorInfo *ignored_error = NULL;
 
 		plugin_service_load (pfo->service, &ignored_error);
 		if (ignored_error != NULL) {
-			error_info_print (ignored_error);
-			error_info_free (ignored_error);
+			go_error_info_print (ignored_error);
+			go_error_info_free (ignored_error);
 			return FALSE;
 		} else if (service_file_opener->cbs.plugin_func_file_probe == NULL) {
 			return FALSE;
@@ -460,14 +460,14 @@ go_plugin_file_opener_open (GOFileOpener const *fo, gchar const *unused_enc,
 {
 	GOPluginFileOpener *pfo = GO_PLUGIN_FILE_OPENER (fo);
 	PluginServiceFileOpener *service_file_opener = GO_PLUGIN_SERVICE_FILE_OPENER (pfo->service);
-	ErrorInfo *error = NULL;
+	GOErrorInfo *error = NULL;
 
 	g_return_if_fail (GSF_IS_INPUT (input));
 
 	plugin_service_load (pfo->service, &error);
 	if (error != NULL) {
-		gnumeric_io_error_info_set (io_context, error);
-		gnumeric_io_error_push (io_context, error_info_new_str (
+		gnumeric_io_go_error_info_set (io_context, error);
+		gnumeric_io_error_push (io_context, go_error_info_new_str (
 		                        _("Error while reading file.")));
 		return;
 	}
@@ -581,7 +581,7 @@ plugin_service_file_saver_finalize (GObject *obj)
 }
 
 static void
-plugin_service_file_saver_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+plugin_service_file_saver_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	xmlNode *information_node;
 	gchar *description;
@@ -636,12 +636,12 @@ plugin_service_file_saver_read_xml (GOPluginService *service, xmlNode *tree, Err
 		if (!xml_node_get_bool (tree, "overwrite_files", &(psfs->overwrite_files)))
 			psfs->overwrite_files = TRUE;
 	} else {
-		*ret_error = error_info_new_str (_("File saver has no description"));
+		*ret_error = go_error_info_new_str (_("File saver has no description"));
 	}
 }
 
 static void
-plugin_service_file_saver_activate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_file_saver_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	PluginServiceFileSaver *service_file_saver = GO_PLUGIN_SERVICE_FILE_SAVER (service);
 	GHashTable *file_savers_hash;
@@ -661,7 +661,7 @@ plugin_service_file_saver_activate (GOPluginService *service, ErrorInfo **ret_er
 }
 
 static void
-plugin_service_file_saver_deactivate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_file_saver_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	PluginServiceFileSaver *service_file_saver = GO_PLUGIN_SERVICE_FILE_SAVER (service);
 	GHashTable *file_savers_hash;
@@ -731,14 +731,14 @@ go_plugin_file_saver_save (GOFileSaver const *fs, IOContext *io_context,
 {
 	GOPluginFileSaver *pfs = GO_PLUGIN_FILE_SAVER (fs);
 	PluginServiceFileSaver *service_file_saver = GO_PLUGIN_SERVICE_FILE_SAVER (pfs->service);
-	ErrorInfo *error = NULL;
+	GOErrorInfo *error = NULL;
 
 	g_return_if_fail (GSF_IS_OUTPUT (output));
 
 	plugin_service_load (pfs->service, &error);
 	if (error != NULL) {
-		gnumeric_io_error_info_set (io_context, error);
-		gnumeric_io_error_push (io_context, error_info_new_str (
+		gnumeric_io_go_error_info_set (io_context, error);
+		gnumeric_io_error_push (io_context, go_error_info_new_str (
 		                        _("Error while loading plugin for saving.")));
 		if (!gsf_output_error (output))
 			gsf_output_set_error (output, 0, _("Failed to load plugin for saving"));
@@ -812,10 +812,10 @@ plugin_service_plugin_loader_init (GObject *obj)
 }
 
 GType
-plugin_service_plugin_loader_generate_type (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_plugin_loader_generate_type (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	PluginServicePluginLoader *service_plugin_loader = GO_PLUGIN_SERVICE_PLUGIN_LOADER (service);
-	ErrorInfo *error = NULL;
+	GOErrorInfo *error = NULL;
 	GType loader_type;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
@@ -827,7 +827,7 @@ plugin_service_plugin_loader_generate_type (GOPluginService *service, ErrorInfo
 			return loader_type;
 		*ret_error = error;
 	} else {
-		*ret_error = error_info_new_str_with_details (
+		*ret_error = go_error_info_new_str_with_details (
 		             _("Error while loading plugin service."),
 		             error);
 	}
@@ -835,7 +835,7 @@ plugin_service_plugin_loader_generate_type (GOPluginService *service, ErrorInfo
 }
 
 static void
-plugin_service_plugin_loader_activate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_plugin_loader_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	gchar *full_id;
 
@@ -848,7 +848,7 @@ plugin_service_plugin_loader_activate (GOPluginService *service, ErrorInfo **ret
 }
 
 static void
-plugin_service_plugin_loader_deactivate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_plugin_loader_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	gchar *full_id;
 
@@ -893,7 +893,7 @@ plugin_service_gobject_loader_get_description (GOPluginService *service)
 static void
 plugin_service_gobject_loader_read_xml (GOPluginService *service,
 					G_GNUC_UNUSED xmlNode *tree,
-					G_GNUC_UNUSED ErrorInfo **ret_error)
+					G_GNUC_UNUSED GOErrorInfo **ret_error)
 {
 	PluginServiceGObjectLoaderClass *gobj_loader_class = GPS_GOBJECT_LOADER_GET_CLASS (service);
 	g_return_if_fail (gobj_loader_class->pending != NULL);
@@ -919,13 +919,13 @@ GSF_CLASS (PluginServiceGObjectLoader, plugin_service_gobject_loader,
  */
 
 static void
-plugin_service_simple_activate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_simple_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	service->is_active = TRUE;
 }
 
 static void
-plugin_service_simple_deactivate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_simple_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	service->is_active = FALSE;
 }
@@ -947,7 +947,7 @@ GSF_CLASS (PluginServiceSimple, plugin_service_simple,
 /* ---------------------------------------------------------------------- */
 
 void
-plugin_service_load (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_load (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	g_return_if_fail (GO_IS_PLUGIN_SERVICE (service));
 
@@ -961,9 +961,9 @@ plugin_service_load (GOPluginService *service, ErrorInfo **ret_error)
 }
 
 void
-plugin_service_unload (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_unload (GOPluginService *service, GOErrorInfo **ret_error)
 {
-	ErrorInfo *error = NULL;
+	GOErrorInfo *error = NULL;
 
 	g_return_if_fail (GO_IS_PLUGIN_SERVICE (service));
 
@@ -980,11 +980,11 @@ plugin_service_unload (GOPluginService *service, ErrorInfo **ret_error)
 }
 
 GOPluginService *
-plugin_service_new (GOPlugin *plugin, xmlNode *tree, ErrorInfo **ret_error)
+plugin_service_new (GOPlugin *plugin, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	GOPluginService *service = NULL;
 	char *type_str;
-	ErrorInfo *service_error = NULL;
+	GOErrorInfo *service_error = NULL;
 	GOPluginServiceCreate ctor;
 
 	g_return_val_if_fail (GO_IS_PLUGIN (plugin), NULL);
@@ -994,13 +994,13 @@ plugin_service_new (GOPlugin *plugin, xmlNode *tree, ErrorInfo **ret_error)
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	type_str = xml_node_get_cstr (tree, "type");
 	if (type_str == NULL) {
-		*ret_error = error_info_new_str (_("No \"type\" attribute on \"service\" element."));
+		*ret_error = go_error_info_new_str (_("No \"type\" attribute on \"service\" element."));
 		return NULL;
 	}
 
 	ctor = g_hash_table_lookup (services, type_str);
 	if (ctor == NULL) {
-		*ret_error = error_info_new_printf (_("Unknown service type: %s."), type_str);
+		*ret_error = go_error_info_new_printf (_("Unknown service type: %s."), type_str);
 		g_free (type_str);
 		return NULL;
 	}
@@ -1015,7 +1015,7 @@ plugin_service_new (GOPlugin *plugin, xmlNode *tree, ErrorInfo **ret_error)
 	if (GPS_GET_CLASS (service)->read_xml != NULL) {
 		GPS_GET_CLASS (service)->read_xml (service, tree, &service_error);
 		if (service_error != NULL) {
-			*ret_error = error_info_new_str_with_details (
+			*ret_error = go_error_info_new_str_with_details (
 				_("Error reading service information."), service_error);
 			g_object_unref (service);
 			service = NULL;
@@ -1063,7 +1063,7 @@ plugin_service_get_cbs (GOPluginService *service)
 }
 
 void
-plugin_service_activate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	g_return_if_fail (GO_IS_PLUGIN_SERVICE (service));
 
@@ -1073,11 +1073,11 @@ plugin_service_activate (GOPluginService *service, ErrorInfo **ret_error)
 	}
 #ifdef PLUGIN_ALWAYS_LOAD
 	{
-		ErrorInfo *load_error = NULL;
+		GOErrorInfo *load_error = NULL;
 
 		plugin_service_load (service, &load_error);
 		if (load_error != NULL) {
-			*ret_error = error_info_new_str_with_details (
+			*ret_error = go_error_info_new_str_with_details (
 				_("We must load service before activating it (PLUGIN_ALWAYS_LOAD is set) "
 				  "but loading failed."), load_error);
 			return;
@@ -1088,7 +1088,7 @@ plugin_service_activate (GOPluginService *service, ErrorInfo **ret_error)
 }
 
 void
-plugin_service_deactivate (GOPluginService *service, ErrorInfo **ret_error)
+plugin_service_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	g_return_if_fail (GO_IS_PLUGIN_SERVICE (service));
 
@@ -1098,12 +1098,12 @@ plugin_service_deactivate (GOPluginService *service, ErrorInfo **ret_error)
 	}
 	GPS_GET_CLASS (service)->deactivate (service, ret_error);
 	if (*ret_error == NULL) {
-		ErrorInfo *ignored_error = NULL;
+		GOErrorInfo *ignored_error = NULL;
 
 		service->is_active = FALSE;
 		/* FIXME */
 		plugin_service_unload (service, &ignored_error);
-		error_info_free (ignored_error);
+		go_error_info_free (ignored_error);
 	}
 }
 
diff --git a/goffice/app/go-plugin-service.h b/goffice/app/go-plugin-service.h
index aa46bd8..8668b92 100644
--- a/goffice/app/go-plugin-service.h
+++ b/goffice/app/go-plugin-service.h
@@ -23,8 +23,8 @@ GType plugin_service_get_type (void);
 GType plugin_service_general_get_type (void);
 typedef struct _PluginServiceGeneral PluginServiceGeneral;
 typedef struct {
-	void (*plugin_func_init) (GOPluginService *service, ErrorInfo **ret_error);
-	void (*plugin_func_cleanup) (GOPluginService *service, ErrorInfo **ret_error);
+	void (*plugin_func_init) (GOPluginService *service, GOErrorInfo **ret_error);
+	void (*plugin_func_cleanup) (GOPluginService *service, GOErrorInfo **ret_error);
 } PluginServiceGeneralCallbacks;
 
 #define GO_TYPE_PLUGIN_SERVICE_FILE_OPENER  (plugin_service_file_opener_get_type ())
@@ -66,11 +66,11 @@ GType plugin_service_plugin_loader_get_type (void);
 typedef struct _PluginServicePluginLoader PluginServicePluginLoader;
 typedef struct {
 	GType (*plugin_func_get_loader_type) (
-	      GOPluginService *service, ErrorInfo **ret_error);
+	      GOPluginService *service, GOErrorInfo **ret_error);
 } PluginServicePluginLoaderCallbacks;
 
 GType plugin_service_plugin_loader_generate_type (GOPluginService *service,
-                                                  ErrorInfo **ret_error);
+                                                  GOErrorInfo **ret_error);
 
 /****************************************************************************/
 
@@ -91,15 +91,15 @@ typedef struct _PluginServiceSimple PluginServiceSimple;
 
 /****************************************************************************/
 
-GOPluginService  *plugin_service_new (GOPlugin *plugin, xmlNode *tree, ErrorInfo **ret_error);
+GOPluginService  *plugin_service_new (GOPlugin *plugin, xmlNode *tree, GOErrorInfo **ret_error);
 char const     *plugin_service_get_id (const GOPluginService *service);
 char const     *plugin_service_get_description (GOPluginService *service);
 GOPlugin      *plugin_service_get_plugin (GOPluginService *service);
 gpointer	plugin_service_get_cbs (GOPluginService *service);
-void		plugin_service_activate (GOPluginService *service, ErrorInfo **ret_error);
-void		plugin_service_deactivate (GOPluginService *service, ErrorInfo **ret_error);
-void		plugin_service_load   (GOPluginService *service, ErrorInfo **ret_error);
-void		plugin_service_unload (GOPluginService *service, ErrorInfo **ret_error);
+void		plugin_service_activate (GOPluginService *service, GOErrorInfo **ret_error);
+void		plugin_service_deactivate (GOPluginService *service, GOErrorInfo **ret_error);
+void		plugin_service_load   (GOPluginService *service, GOErrorInfo **ret_error);
+void		plugin_service_unload (GOPluginService *service, GOErrorInfo **ret_error);
 
 typedef GType (*GOPluginServiceCreate) (void);
 void plugin_services_init     (void);
diff --git a/goffice/app/go-plugin.c b/goffice/app/go-plugin.c
index a257ed7..cd8b405 100644
--- a/goffice/app/go-plugin.c
+++ b/goffice/app/go-plugin.c
@@ -57,9 +57,9 @@ static GHashTable *available_plugins_id_hash = NULL;
 static GHashTable *loader_services = NULL;
 static GType	   go_default_loader_type;
 
-static void plugin_get_loader_if_needed (GOPlugin *plugin, ErrorInfo **ret_error);
-static void go_plugin_read (GOPlugin *plugin, gchar const *dir_name, ErrorInfo **ret_error);
-static void go_plugin_load_base (GOPlugin *plugin, ErrorInfo **ret_error);
+static void plugin_get_loader_if_needed (GOPlugin *plugin, GOErrorInfo **ret_error);
+static void go_plugin_read (GOPlugin *plugin, gchar const *dir_name, GOErrorInfo **ret_error);
+static void go_plugin_load_base (GOPlugin *plugin, GOErrorInfo **ret_error);
 
 /*
  * GOPlugin
@@ -204,10 +204,10 @@ GSF_CLASS (GOPlugin, go_plugin, go_plugin_class_init, go_plugin_init,
            G_TYPE_OBJECT)
 
 static GOPlugin *
-go_plugin_new_from_xml (gchar const *dir_name, ErrorInfo **ret_error)
+go_plugin_new_from_xml (gchar const *dir_name, GOErrorInfo **ret_error)
 {
 	GOPlugin *plugin;
-	ErrorInfo *error;
+	GOErrorInfo *error;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	plugin = g_object_new (GO_TYPE_PLUGIN, NULL);
@@ -306,9 +306,9 @@ plugin_file_state_free (gpointer data)
 /* --- */
 
 static gboolean
-go_plugin_read_full_info_if_needed_error_info (GOPlugin *plugin, ErrorInfo **ret_error)
+go_plugin_read_full_info_if_needed_go_error_info_ (GOPlugin *plugin, GOErrorInfo **ret_error)
 {
-	ErrorInfo *read_error;
+	GOErrorInfo *read_error;
 	gchar *old_id, *old_dir_name;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
@@ -329,11 +329,11 @@ go_plugin_read_full_info_if_needed_error_info (GOPlugin *plugin, ErrorInfo **ret
 	} else {
 		go_plugin_message (1, "Can't read plugin.xml file for %s.\n", old_id);
 		if (read_error == NULL) {
-			read_error = error_info_new_printf (
+			read_error = go_error_info_new_printf (
 			             _("File contains plugin info with invalid id (%s), expected %s."),
 			             plugin->id, old_id);
 		}
-		*ret_error = error_info_new_str_with_details (
+		*ret_error = go_error_info_new_str_with_details (
 		             _("Couldn't read plugin info from file."),
 		             read_error);
 		g_free (old_id);
@@ -346,14 +346,14 @@ go_plugin_read_full_info_if_needed_error_info (GOPlugin *plugin, ErrorInfo **ret
 static gboolean
 go_plugin_read_full_info_if_needed (GOPlugin *plugin)
 {
-	ErrorInfo *error;
+	GOErrorInfo *error;
 
-	if (go_plugin_read_full_info_if_needed_error_info (plugin, &error)) {
+	if (go_plugin_read_full_info_if_needed_go_error_info_ (plugin, &error)) {
 		return TRUE;
 	} else {
 		g_warning ("go_plugin_read_full_info_if_needed: couldn't read plugin info from file.");
-		error_info_print (error);
-		error_info_free (error);
+		go_error_info_print (error);
+		go_error_info_free (error);
 		return FALSE;
 	}
 }
@@ -559,10 +559,10 @@ go_plugins_unregister_loader (gchar const *loader_id)
 }
 
 static GType
-get_loader_type_by_id (gchar const *id_str, ErrorInfo **ret_error)
+get_loader_type_by_id (gchar const *id_str, GOErrorInfo **ret_error)
 {
 	GOPluginService *loader_service;
-	ErrorInfo *error;
+	GOErrorInfo *error;
 	GType loader_type;
 
 	g_return_val_if_fail (id_str != NULL, G_TYPE_NONE);
@@ -573,7 +573,7 @@ get_loader_type_by_id (gchar const *id_str, ErrorInfo **ret_error)
 
 	loader_service = g_hash_table_lookup (loader_services, id_str);
 	if (loader_service == NULL) {
-		*ret_error = error_info_new_printf (
+		*ret_error = go_error_info_new_printf (
 		             _("Unsupported loader type \"%s\"."),
 		             id_str);
 		return G_TYPE_NONE;
@@ -581,10 +581,10 @@ get_loader_type_by_id (gchar const *id_str, ErrorInfo **ret_error)
 	loader_type = plugin_service_plugin_loader_generate_type (
 	              loader_service, &error);
 	if (error != NULL) {
-		*ret_error = error_info_new_printf (
+		*ret_error = go_error_info_new_printf (
 		             _("Error while preparing loader \"%s\"."),
 		             id_str);
-		error_info_add_details (*ret_error, error);
+		go_error_info_add_details (*ret_error, error);
 		return G_TYPE_NONE;
 	}
 
@@ -632,7 +632,7 @@ go_plugin_read_dependency_list (xmlNode *tree)
 }
 
 static GSList *
-go_plugin_read_service_list (GOPlugin *plugin, xmlNode *tree, ErrorInfo **ret_error)
+go_plugin_read_service_list (GOPlugin *plugin, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	GSList *service_list = NULL;
 	GSList *error_list = NULL;
@@ -649,7 +649,7 @@ go_plugin_read_service_list (GOPlugin *plugin, xmlNode *tree, ErrorInfo **ret_er
 	for (i = 0; node != NULL; i++, node = node->next) {
 		if (strcmp (node->name, "service") == 0) {
 			GOPluginService *service;
-			ErrorInfo *service_error;
+			GOErrorInfo *service_error;
 
 			service = plugin_service_new (plugin, node, &service_error);
 
@@ -657,19 +657,19 @@ go_plugin_read_service_list (GOPlugin *plugin, xmlNode *tree, ErrorInfo **ret_er
 				g_assert (service_error == NULL);
 				GO_SLIST_PREPEND (service_list, service);
 			} else {
-				ErrorInfo *error;
+				GOErrorInfo *error;
 
-				error = error_info_new_printf (
+				error = go_error_info_new_printf (
 				        _("Error while reading service #%d info."),
 				        i);
-				error_info_add_details (error, service_error);
+				go_error_info_add_details (error, service_error);
 				GO_SLIST_PREPEND (error_list, error);
 			}
 		}
 	}
 	if (error_list != NULL) {
 		GO_SLIST_REVERSE (error_list);
-		*ret_error = error_info_new_from_error_list (error_list);
+		*ret_error = go_error_info_new_from_error_list (error_list);
 		go_slist_free_custom (service_list, g_object_unref);
 		return NULL;
 	} else {
@@ -719,7 +719,7 @@ plugin_dependency_free (gpointer data)
 }
 
 static void
-go_plugin_read (GOPlugin *plugin, gchar const *dir_name, ErrorInfo **ret_error)
+go_plugin_read (GOPlugin *plugin, gchar const *dir_name, GOErrorInfo **ret_error)
 {
 	gchar *file_name;
 	xmlDocPtr doc;
@@ -739,11 +739,11 @@ go_plugin_read (GOPlugin *plugin, gchar const *dir_name, ErrorInfo **ret_error)
 	if (doc == NULL || doc->xmlRootNode == NULL || strcmp (doc->xmlRootNode->name, "plugin") != 0) {
 		char *uri = go_filename_to_uri (file_name);
 		if (go_file_access (uri, R_OK) != 0) {
-			*ret_error = error_info_new_printf (
+			*ret_error = go_error_info_new_printf (
 			             _("Can't read plugin info file (\"%s\")."),
 			             file_name);
 		} else {
-			*ret_error = error_info_new_printf (
+			*ret_error = go_error_info_new_printf (
 			             _("File \"%s\" is not valid plugin info file."),
 			             file_name);
 		}
@@ -813,7 +813,7 @@ go_plugin_read (GOPlugin *plugin, gchar const *dir_name, ErrorInfo **ret_error)
 	}
 	if (id != NULL && name != NULL && loader_id != NULL &&
 	    id[strspn (id, PLUGIN_ID_VALID_CHARS)] == '\0') {
-		ErrorInfo *services_error = NULL;
+		GOErrorInfo *services_error = NULL;
 		plugin->dir_name = g_strdup (dir_name);
 		plugin->id = id;
 		plugin->name = name;
@@ -829,10 +829,10 @@ go_plugin_read (GOPlugin *plugin, gchar const *dir_name, ErrorInfo **ret_error)
 		plugin->services = go_plugin_read_service_list (plugin, tree, &services_error);
 
 		if (services_error != NULL) {
-			*ret_error = error_info_new_printf (
+			*ret_error = go_error_info_new_printf (
 				_("Errors while reading services for plugin with id=\"%s\"."),
 				id);
-			error_info_add_details (*ret_error, services_error);
+			go_error_info_add_details (*ret_error, services_error);
 		} else
 			go_plugin_message (4, "Read plugin.xml file for %s.\n", plugin->id);
 	} else {
@@ -840,22 +840,22 @@ go_plugin_read (GOPlugin *plugin, gchar const *dir_name, ErrorInfo **ret_error)
 			GSList *error_list = NULL;
 
 			if (id[strspn (id, PLUGIN_ID_VALID_CHARS)] != '\0') {
-				GO_SLIST_PREPEND (error_list, error_info_new_printf (
+				GO_SLIST_PREPEND (error_list, go_error_info_new_printf (
 					_("Plugin id contains invalid characters (%s)."), id));
 			}
 			if (name == NULL) {
-				GO_SLIST_PREPEND (error_list, error_info_new_str (
+				GO_SLIST_PREPEND (error_list, go_error_info_new_str (
 					_("Unknown plugin name.")));
 			}
 			if (loader_id == NULL) {
-				GO_SLIST_PREPEND (error_list, error_info_new_printf (
+				GO_SLIST_PREPEND (error_list, go_error_info_new_printf (
 					_("No loader defined or loader id invalid for plugin with id=\"%s\"."), id));
 			}
 			g_assert (error_list != NULL);
 			GO_SLIST_REVERSE (error_list);
-			*ret_error = error_info_new_from_error_list (error_list);
+			*ret_error = go_error_info_new_from_error_list (error_list);
 		} else
-			*ret_error = error_info_new_str (_("Plugin has no id."));
+			*ret_error = go_error_info_new_str (_("Plugin has no id."));
 
 		go_slist_free_custom (dependency_list, plugin_dependency_free);
 		g_free (plugin->loader_id);
@@ -870,15 +870,15 @@ go_plugin_read (GOPlugin *plugin, gchar const *dir_name, ErrorInfo **ret_error)
 }
 
 static void
-plugin_get_loader_if_needed (GOPlugin *plugin, ErrorInfo **ret_error)
+plugin_get_loader_if_needed (GOPlugin *plugin, GOErrorInfo **ret_error)
 {
 	GType loader_type;
-	ErrorInfo *error = NULL;
+	GOErrorInfo *error = NULL;
 
 	g_return_if_fail (GO_IS_PLUGIN (plugin));
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
-	if (!go_plugin_read_full_info_if_needed_error_info (plugin, ret_error)) {
+	if (!go_plugin_read_full_info_if_needed_go_error_info_ (plugin, ret_error)) {
 		return;
 	}
 	if (plugin->loader != NULL) {
@@ -886,7 +886,7 @@ plugin_get_loader_if_needed (GOPlugin *plugin, ErrorInfo **ret_error)
 	}
 	loader_type = get_loader_type_by_id (plugin->loader_id, &error);
 	if (error == NULL) {
-		ErrorInfo *error;
+		GOErrorInfo *error;
 		GOPluginLoader *loader = g_object_new (loader_type, NULL);
 		go_plugin_loader_set_attributes (loader, plugin->loader_attrs, &error);
 		if (error == NULL) {
@@ -895,10 +895,10 @@ plugin_get_loader_if_needed (GOPlugin *plugin, ErrorInfo **ret_error)
 		} else {
 			g_object_unref (loader);
 			loader = NULL;
-			*ret_error = error_info_new_printf (
+			*ret_error = go_error_info_new_printf (
 			             _("Error initializing plugin loader (\"%s\")."),
 			             plugin->loader_id);
-			error_info_add_details (*ret_error, error);
+			go_error_info_add_details (*ret_error, error);
 		}
 	} else {
 		*ret_error = error;
@@ -915,7 +915,7 @@ plugin_get_loader_if_needed (GOPlugin *plugin, ErrorInfo **ret_error)
  * information will be returned using @ret_error.
  */
 void
-go_plugin_activate (GOPlugin *plugin, ErrorInfo **ret_error)
+go_plugin_activate (GOPlugin *plugin, GOErrorInfo **ret_error)
 {
 	GSList *error_list = NULL;
 	GSList *l;
@@ -926,11 +926,11 @@ go_plugin_activate (GOPlugin *plugin, ErrorInfo **ret_error)
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	if (g_slist_find (activate_stack, plugin) != NULL) {
-		*ret_error = error_info_new_str (
+		*ret_error = go_error_info_new_str (
 				     _("Detected cyclic plugin dependencies."));
 		return;
 	}
-	if (!go_plugin_read_full_info_if_needed_error_info (plugin, ret_error)) {
+	if (!go_plugin_read_full_info_if_needed_go_error_info_ (plugin, ret_error)) {
 		return;
 	}
 	if (plugin->is_active) {
@@ -944,47 +944,47 @@ go_plugin_activate (GOPlugin *plugin, ErrorInfo **ret_error)
 
 		dep_plugin = plugin_dependency_get_plugin (dep);
 		if (dep_plugin != NULL) {
-			ErrorInfo *dep_error;
+			GOErrorInfo *dep_error;
 
 			go_plugin_activate (dep_plugin, &dep_error);
 			if (dep_error != NULL) {
-				ErrorInfo *new_error;
+				GOErrorInfo *new_error;
 
-				new_error = error_info_new_printf (
+				new_error = go_error_info_new_printf (
 					_("Couldn't activate plugin with id=\"%s\"."), dep->plugin_id);
-				error_info_add_details (new_error, dep_error);
+				go_error_info_add_details (new_error, dep_error);
 				GO_SLIST_PREPEND (error_list, new_error);
 			}
 		} else {
-			GO_SLIST_PREPEND (error_list, error_info_new_printf (
+			GO_SLIST_PREPEND (error_list, go_error_info_new_printf (
 				_("Couldn't find plugin with id=\"%s\"."), dep->plugin_id));
 		}
 	);
 	g_assert (activate_stack != NULL && activate_stack->data == plugin);
 	activate_stack = g_slist_delete_link (activate_stack, activate_stack);
 	if (error_list != NULL) {
-		*ret_error = error_info_new_str (
+		*ret_error = go_error_info_new_str (
 				     _("Error while activating plugin dependencies."));
-		error_info_add_details_list (*ret_error, error_list);
+		go_error_info_add_details_list (*ret_error, error_list);
 		return;
 	}
 
 	for (l = plugin->services, i = 0; l != NULL; l = l->next, i++) {
 		GOPluginService *service = l->data;
-		ErrorInfo *service_error;
+		GOErrorInfo *service_error;
 
 		plugin_service_activate (service, &service_error);
 		if (service_error != NULL) {
-			ErrorInfo *error;
+			GOErrorInfo *error;
 
-			error = error_info_new_printf (
+			error = go_error_info_new_printf (
 				_("Error while activating plugin service #%d."), i);
-			error_info_add_details (error, service_error);
+			go_error_info_add_details (error, service_error);
 			GO_SLIST_PREPEND (error_list, error);
 		}
 	}
 	if (error_list != NULL) {
-		*ret_error = error_info_new_from_error_list (error_list);
+		*ret_error = go_error_info_new_from_error_list (error_list);
 		/* FIXME - deactivate activated services */
 		return;
 	}
@@ -1006,7 +1006,7 @@ go_plugin_activate (GOPlugin *plugin, ErrorInfo **ret_error)
  * information will be returned using @ret_error.
  */
 void
-go_plugin_deactivate (GOPlugin *plugin, ErrorInfo **ret_error)
+go_plugin_deactivate (GOPlugin *plugin, GOErrorInfo **ret_error)
 {
 	GSList *error_list = NULL;
 	GSList *l;
@@ -1019,25 +1019,25 @@ go_plugin_deactivate (GOPlugin *plugin, ErrorInfo **ret_error)
 		return;
 	}
 	if (plugin->use_refcount > 0) {
-		*ret_error = error_info_new_str ("Plugin is still in use.");
+		*ret_error = go_error_info_new_str ("Plugin is still in use.");
 		return;
 	}
 	for (l = plugin->services, i = 0; l != NULL; l = l->next, i++) {
 		GOPluginService *service = l->data;
-		ErrorInfo *service_error;
+		GOErrorInfo *service_error;
 
 		plugin_service_deactivate (service, &service_error);
 		if (service_error != NULL) {
-			ErrorInfo *error;
+			GOErrorInfo *error;
 
-			error = error_info_new_printf (
+			error = go_error_info_new_printf (
 				_("Error while deactivating plugin service #%d."), i);
-			error_info_add_details (error, service_error);
+			go_error_info_add_details (error, service_error);
 			GO_SLIST_PREPEND (error_list, error);
 		}
 	}
 	if (error_list != NULL) {
-		*ret_error = error_info_new_from_error_list (error_list);
+		*ret_error = go_error_info_new_from_error_list (error_list);
 		/* FIXME - some services are still active (or broken) */
 	} else {
 		plugin->is_active = FALSE;
@@ -1077,27 +1077,27 @@ go_plugin_can_deactivate (GOPlugin *plugin)
 }
 
 static void
-go_plugin_load_base (GOPlugin *plugin, ErrorInfo **ret_error)
+go_plugin_load_base (GOPlugin *plugin, GOErrorInfo **ret_error)
 {
-	ErrorInfo *error;
+	GOErrorInfo *error;
 	GSList *error_list = NULL;
 	static GSList *load_stack = NULL;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	if (g_slist_find (load_stack, plugin) != NULL) {
-		*ret_error = error_info_new_str (
+		*ret_error = go_error_info_new_str (
 				     _("Detected cyclic plugin dependencies."));
 		return;
 	}
 	if (go_plugin_is_loaded (plugin)) {
 		return;
 	}
-	if (!go_plugin_read_full_info_if_needed_error_info (plugin, ret_error)) {
+	if (!go_plugin_read_full_info_if_needed_go_error_info_ (plugin, ret_error)) {
 		return;
 	}
 	plugin_get_loader_if_needed (plugin, &error);
 	if (error != NULL) {
-		*ret_error = error_info_new_str_with_details (
+		*ret_error = go_error_info_new_str_with_details (
 		             _("Cannot load plugin loader."),
 		             error);
 		return;
@@ -1107,7 +1107,7 @@ go_plugin_load_base (GOPlugin *plugin, ErrorInfo **ret_error)
 	GO_SLIST_PREPEND (load_stack, plugin);
 	GO_SLIST_FOREACH (plugin->dependencies, PluginDependency, dep,
 		GOPlugin *dep_plugin;
-		ErrorInfo *dep_error;
+		GOErrorInfo *dep_error;
 
 		if (!dep->force_load) {
 			continue;
@@ -1118,29 +1118,29 @@ go_plugin_load_base (GOPlugin *plugin, ErrorInfo **ret_error)
 			if (dep_error == NULL) {
 				go_plugin_load_base (dep_plugin, &dep_error);
 			} else {
-				dep_error = error_info_new_str_with_details (
+				dep_error = go_error_info_new_str_with_details (
 				             _("Cannot load plugin loader."),
 				             dep_error);
 			}
 			if (dep_error != NULL) {
-				ErrorInfo *new_error;
+				GOErrorInfo *new_error;
 
-				new_error = error_info_new_printf (
+				new_error = go_error_info_new_printf (
 					_("Couldn't load plugin with id=\"%s\"."), dep->plugin_id);
-				error_info_add_details (new_error, dep_error);
+				go_error_info_add_details (new_error, dep_error);
 				GO_SLIST_PREPEND (error_list, new_error);
 			}
 		} else {
-			GO_SLIST_PREPEND (error_list, error_info_new_printf (
+			GO_SLIST_PREPEND (error_list, go_error_info_new_printf (
 				_("Couldn't find plugin with id=\"%s\"."), dep->plugin_id));
 		}
 	);
 	g_assert (load_stack != NULL && load_stack->data == plugin);
 	load_stack = g_slist_delete_link (load_stack, load_stack);
 	if (error_list != NULL) {
-		*ret_error = error_info_new_str (
+		*ret_error = go_error_info_new_str (
 				     _("Error while loading plugin dependencies."));
-		error_info_add_details_list (*ret_error, error_list);
+		go_error_info_add_details_list (*ret_error, error_list);
 		return;
 	}
 
@@ -1163,7 +1163,7 @@ go_plugin_load_base (GOPlugin *plugin, ErrorInfo **ret_error)
  * This function is intended for use by GOPluginService objects.
  */
 void
-go_plugin_load_service (GOPlugin *plugin, GOPluginService *service, ErrorInfo **ret_error)
+go_plugin_load_service (GOPlugin *plugin, GOPluginService *service, GOErrorInfo **ret_error)
 {
 	g_return_if_fail (GO_IS_PLUGIN (plugin));
 	g_return_if_fail (service != NULL);
@@ -1186,14 +1186,14 @@ go_plugin_load_service (GOPlugin *plugin, GOPluginService *service, ErrorInfo **
  * This function is intended for use by GOPluginService objects.
  */
 void
-go_plugin_unload_service (GOPlugin *plugin, GOPluginService *service, ErrorInfo **ret_error)
+go_plugin_unload_service (GOPlugin *plugin, GOPluginService *service, GOErrorInfo **ret_error)
 {
 	g_return_if_fail (GO_IS_PLUGIN (plugin));
 	g_return_if_fail (plugin->loader != NULL);
 	g_return_if_fail (service != NULL);
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
-	if (!go_plugin_read_full_info_if_needed_error_info (plugin, ret_error)) {
+	if (!go_plugin_read_full_info_if_needed_go_error_info_ (plugin, ret_error)) {
 		return;
 	}
 	go_plugin_loader_unload_service (plugin->loader, service, ret_error);
@@ -1272,13 +1272,13 @@ go_plugin_get_services (GOPlugin *plugin)
  * May return NULL without errors (is XML file doesn't exist)
  */
 static GOPlugin *
-go_plugin_read_for_dir (gchar const *dir_name, ErrorInfo **ret_error)
+go_plugin_read_for_dir (gchar const *dir_name, GOErrorInfo **ret_error)
 {
 	GOPlugin *plugin = NULL;
 	gchar *file_name;
 	gchar *file_state;
 	PluginFileState *state;
-	ErrorInfo *plugin_error;
+	GOErrorInfo *plugin_error;
 
 	g_return_val_if_fail (dir_name != NULL, NULL);
 
@@ -1315,10 +1315,10 @@ go_plugin_read_for_dir (gchar const *dir_name, ErrorInfo **ret_error)
 		}
 		plugin_file_state_hash_changed = TRUE;
 	} else {
-		*ret_error = error_info_new_printf (
+		*ret_error = go_error_info_new_printf (
 		             _("Errors occurred while reading plugin informations from file \"%s\"."),
 		             file_name);
-		error_info_add_details (*ret_error, plugin_error);
+		go_error_info_add_details (*ret_error, plugin_error);
 	}
 	g_free (file_name);
 	g_free (file_state);
@@ -1330,7 +1330,7 @@ go_plugin_read_for_dir (gchar const *dir_name, ErrorInfo **ret_error)
  * May return partial list and some error info.
  */
 static GSList *
-go_plugin_list_read_for_subdirs_of_dir (gchar const *dir_name, ErrorInfo **ret_error)
+go_plugin_list_read_for_subdirs_of_dir (gchar const *dir_name, GOErrorInfo **ret_error)
 {
 	GSList *plugins = NULL;
 	GDir *dir;
@@ -1346,7 +1346,7 @@ go_plugin_list_read_for_subdirs_of_dir (gchar const *dir_name, ErrorInfo **ret_e
 
 	while ((d_name = g_dir_read_name (dir)) != NULL) {
 		gchar *full_entry_name;
-		ErrorInfo *error = NULL;
+		GOErrorInfo *error = NULL;
 		GOPlugin *plugin;
 
 		if (strcmp (d_name, ".") == 0 || strcmp (d_name, "..") == 0)
@@ -1363,7 +1363,7 @@ go_plugin_list_read_for_subdirs_of_dir (gchar const *dir_name, ErrorInfo **ret_e
 	}
 	if (error_list != NULL) {
 		GO_SLIST_REVERSE (error_list);
-		*ret_error = error_info_new_from_error_list (error_list);
+		*ret_error = go_error_info_new_from_error_list (error_list);
 	}
 	g_dir_close (dir);
 
@@ -1374,7 +1374,7 @@ go_plugin_list_read_for_subdirs_of_dir (gchar const *dir_name, ErrorInfo **ret_e
  * May return partial list and some error info.
  */
 static GSList *
-go_plugin_list_read_for_subdirs_of_dir_list (GSList *dir_list, ErrorInfo **ret_error)
+go_plugin_list_read_for_subdirs_of_dir_list (GSList *dir_list, GOErrorInfo **ret_error)
 {
 	GSList *plugins = NULL;
 	GSList *dir_iterator;
@@ -1383,7 +1383,7 @@ go_plugin_list_read_for_subdirs_of_dir_list (GSList *dir_list, ErrorInfo **ret_e
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	for (dir_iterator = dir_list; dir_iterator != NULL; dir_iterator = dir_iterator->next) {
 		gchar *dir_name;
-		ErrorInfo *error = NULL;
+		GOErrorInfo *error = NULL;
 		GSList *dir_plugin_info_list;
 
 		dir_name = (gchar *) dir_iterator->data;
@@ -1397,7 +1397,7 @@ go_plugin_list_read_for_subdirs_of_dir_list (GSList *dir_list, ErrorInfo **ret_e
 	}
 	if (error_list != NULL) {
 		GO_SLIST_REVERSE (error_list);
-		*ret_error = error_info_new_from_error_list (error_list);
+		*ret_error = go_error_info_new_from_error_list (error_list);
 	}
 
 	return plugins;
@@ -1407,7 +1407,7 @@ go_plugin_list_read_for_subdirs_of_dir_list (GSList *dir_list, ErrorInfo **ret_e
  * May return partial list and some error info.
  */
 static GSList *
-go_plugin_list_read_for_all_dirs (ErrorInfo **ret_error)
+go_plugin_list_read_for_all_dirs (GOErrorInfo **ret_error)
 {
 	return go_plugin_list_read_for_subdirs_of_dir_list (go_plugin_dirs, ret_error);
 }
@@ -1422,28 +1422,28 @@ go_plugin_list_read_for_all_dirs (ErrorInfo **ret_error)
  * affect plugins activated successfully).
  */
 void
-go_plugin_db_activate_plugin_list (GSList *plugins, ErrorInfo **ret_error)
+go_plugin_db_activate_plugin_list (GSList *plugins, GOErrorInfo **ret_error)
 {
 	GSList *error_list = NULL;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	GO_SLIST_FOREACH (plugins, GOPlugin, plugin,
-		ErrorInfo *error;
+		GOErrorInfo *error;
 
 		go_plugin_activate (plugin, &error);
 		if (error != NULL) {
-			ErrorInfo *new_error;
+			GOErrorInfo *new_error;
 
-			new_error = error_info_new_printf (
+			new_error = go_error_info_new_printf (
 			            _("Couldn't activate plugin \"%s\" (ID: %s)."),
 			            plugin->name, plugin->id);
-			error_info_add_details (new_error, error);
+			go_error_info_add_details (new_error, error);
 			GO_SLIST_PREPEND (error_list, new_error);
 		}
 	);
 	if (error_list != NULL) {
 		GO_SLIST_REVERSE (error_list);
-		*ret_error = error_info_new_from_error_list (error_list);
+		*ret_error = go_error_info_new_from_error_list (error_list);
 	}
 }
 
@@ -1457,28 +1457,28 @@ go_plugin_db_activate_plugin_list (GSList *plugins, ErrorInfo **ret_error)
  * affect plugins deactivated successfully).
  */
 void
-go_plugin_db_deactivate_plugin_list (GSList *plugins, ErrorInfo **ret_error)
+go_plugin_db_deactivate_plugin_list (GSList *plugins, GOErrorInfo **ret_error)
 {
 	GSList *error_list = NULL;
 
 	GO_INIT_RET_ERROR_INFO (ret_error);
 	GO_SLIST_FOREACH (plugins, GOPlugin, plugin,
-		ErrorInfo *error;
+		GOErrorInfo *error;
 
 		go_plugin_deactivate (plugin, &error);
 		if (error != NULL) {
-			ErrorInfo *new_error;
+			GOErrorInfo *new_error;
 
-			new_error = error_info_new_printf (
+			new_error = go_error_info_new_printf (
 			            _("Couldn't deactivate plugin \"%s\" (ID: %s)."),
 			            plugin->name, plugin->id);
-			error_info_add_details (new_error, error);
+			go_error_info_add_details (new_error, error);
 			GO_SLIST_PREPEND (error_list, new_error);
 		}
 	);
 	if (error_list != NULL) {
 		GO_SLIST_REVERSE (error_list);
-		*ret_error = error_info_new_from_error_list (error_list);
+		*ret_error = go_error_info_new_from_error_list (error_list);
 	}
 }
 
@@ -1580,10 +1580,10 @@ ghf_set_state_old_unused (gpointer key, gpointer value, gpointer unused)
  *
  */
 void
-go_plugins_rescan (ErrorInfo **ret_error, GSList **ret_new_plugins)
+go_plugins_rescan (GOErrorInfo **ret_error, GSList **ret_new_plugins)
 {
 	GSList *error_list = NULL;
-	ErrorInfo *error;
+	GOErrorInfo *error;
 	GSList *new_available_plugins;
 	GHashTable *new_available_plugins_id_hash;
 	GSList *removed_plugins = NULL, *added_plugins = NULL, *still_active_ids = NULL;
@@ -1594,7 +1594,7 @@ go_plugins_rescan (ErrorInfo **ret_error, GSList **ret_new_plugins)
 	g_hash_table_foreach (plugin_file_state_dir_hash, ghf_set_state_old_unused, NULL);
 	new_available_plugins = go_plugin_list_read_for_all_dirs (&error);
 	if (error != NULL) {
-		GO_SLIST_PREPEND (error_list, error_info_new_str_with_details (
+		GO_SLIST_PREPEND (error_list, go_error_info_new_str_with_details (
 			_("Errors while reading info about available plugins."), error));
 	}
 
@@ -1618,7 +1618,7 @@ go_plugins_rescan (ErrorInfo **ret_error, GSList **ret_new_plugins)
 	g_hash_table_destroy (new_available_plugins_id_hash);
 	go_plugin_db_deactivate_plugin_list (removed_plugins, &error);
 	if (error != NULL) {
-		GO_SLIST_PREPEND (error_list, error_info_new_str_with_details (
+		GO_SLIST_PREPEND (error_list, go_error_info_new_str_with_details (
 			_("Errors while deactivating plugins that are no longer on disk."), error));
 	}
 	GO_SLIST_FOREACH (removed_plugins, GOPlugin, plugin,
@@ -1639,7 +1639,7 @@ go_plugins_rescan (ErrorInfo **ret_error, GSList **ret_new_plugins)
 			g_string_append (s, ", ");
 			g_string_append (s, id);
 		);
-		GO_SLIST_PREPEND (error_list, error_info_new_printf (
+		GO_SLIST_PREPEND (error_list, go_error_info_new_printf (
 			_("The following plugins are no longer on disk but are still active:\n"
 			  "%s.\nYou should restart this program now."), s->str));
 		g_string_free (s, TRUE);
@@ -1669,7 +1669,7 @@ go_plugins_rescan (ErrorInfo **ret_error, GSList **ret_new_plugins)
 
 	/* handle errors */
 	if (error_list != NULL) {
-		*ret_error = error_info_new_from_error_list (g_slist_reverse (error_list));
+		*ret_error = go_error_info_new_from_error_list (g_slist_reverse (error_list));
 	}
 }
 
@@ -1715,7 +1715,7 @@ go_plugins_init (GOCmdContext *context,
 		 GType  default_loader_type)
 {
 	GSList *error_list = NULL;
-	ErrorInfo *error;
+	GOErrorInfo *error;
 	GSList *plugin_list;
 
 	plugin_dirs = g_slist_append (plugin_dirs, go_plugins_get_plugin_dir ());
@@ -1745,7 +1745,7 @@ go_plugins_init (GOCmdContext *context,
 			(gpointer) go_plugin_get_id (plugin), plugin);
 	);
 	if (error != NULL) {
-		GO_SLIST_PREPEND (error_list, error_info_new_str_with_details (
+		GO_SLIST_PREPEND (error_list, go_error_info_new_str_with_details (
 			_("Errors while reading info about available plugins."), error));
 	}
 
@@ -1768,19 +1768,19 @@ go_plugins_init (GOCmdContext *context,
 	go_plugin_db_activate_plugin_list (plugin_list, &error);
 	g_slist_free (plugin_list);
 	if (error != NULL) {
-		GO_SLIST_PREPEND (error_list, error_info_new_str_with_details (
+		GO_SLIST_PREPEND (error_list, go_error_info_new_str_with_details (
 			_("Errors while activating plugins."), error));
 	}
 
 	/* report initialization errors */
 	if (error_list != NULL) {
 		GO_SLIST_REVERSE (error_list);
-		error = error_info_new_str_with_details_list (
+		error = go_error_info_new_str_with_details_list (
 		        _("Errors while initializing plugin system."),
 		        error_list);
 
 		go_cmd_context_error_info (context, error);
-		error_info_free (error);
+		go_error_info_free (error);
 	}
 }
 
@@ -1802,7 +1802,7 @@ go_plugins_add (GOCmdContext *context,
 		GType  default_loader_type)
 {
 	GSList *error_list = NULL;
-	ErrorInfo *error;
+	GOErrorInfo *error;
 	GSList *plugin_list;
 
 	plugin_dirs = g_slist_append (plugin_dirs, go_plugins_get_plugin_dir ());
@@ -1828,7 +1828,7 @@ go_plugins_add (GOCmdContext *context,
 			(gpointer) go_plugin_get_id (plugin), plugin);
 	);
 	if (error != NULL) {
-		GO_SLIST_PREPEND (error_list, error_info_new_str_with_details (
+		GO_SLIST_PREPEND (error_list, go_error_info_new_str_with_details (
 			_("Errors while reading info about available plugins."), error));
 	}
 
@@ -1850,19 +1850,19 @@ go_plugins_add (GOCmdContext *context,
 	go_plugin_db_activate_plugin_list (plugin_list, &error);
 	g_slist_free (plugin_list);
 	if (error != NULL) {
-		GO_SLIST_PREPEND (error_list, error_info_new_str_with_details (
+		GO_SLIST_PREPEND (error_list, go_error_info_new_str_with_details (
 			_("Errors while activating plugins."), error));
 	}
 
 	/* report initialization errors */
 	if (error_list != NULL) {
 		GO_SLIST_REVERSE (error_list);
-		error = error_info_new_str_with_details_list (
+		error = go_error_info_new_str_with_details_list (
 		        _("Errors while initializing plugin system."),
 		        error_list);
 
 		go_cmd_context_error_info (context, error);
-		error_info_free (error);
+		go_error_info_free (error);
 	}
 }
 
@@ -1888,7 +1888,7 @@ GSList *
 go_plugins_shutdown (void)
 {
 	GSList *used_plugin_state_strings = NULL;
-	ErrorInfo *ignored_error;
+	GOErrorInfo *ignored_error;
 
 	if (plugins_marked_for_deactivation_hash != NULL) {
 		g_hash_table_destroy (plugins_marked_for_deactivation_hash);
@@ -1896,7 +1896,7 @@ go_plugins_shutdown (void)
 
 	/* deactivate all plugins */
 	go_plugin_db_deactivate_plugin_list (available_plugins, &ignored_error);
-	error_info_free (ignored_error);
+	go_error_info_free (ignored_error);
 
 	/* update information stored in gconf database
 	 * about known plugin.xml files and destroy hash table */
diff --git a/goffice/app/go-plugin.h b/goffice/app/go-plugin.h
index 2115505..7eb1b3d 100644
--- a/goffice/app/go-plugin.h
+++ b/goffice/app/go-plugin.h
@@ -19,12 +19,12 @@ G_BEGIN_DECLS
 
 GType	go_plugin_get_type (void);
 
-void         go_plugin_activate (GOPlugin *plugin, ErrorInfo **ret_error);
-void         go_plugin_deactivate (GOPlugin *plugin, ErrorInfo **ret_error);
+void         go_plugin_activate (GOPlugin *plugin, GOErrorInfo **ret_error);
+void         go_plugin_deactivate (GOPlugin *plugin, GOErrorInfo **ret_error);
 gboolean     go_plugin_is_active (GOPlugin *plugin);
 gboolean     go_plugin_can_deactivate (GOPlugin *plugin);
-void         go_plugin_load_service (GOPlugin *plugin, GOPluginService *service, ErrorInfo **ret_error);
-void         go_plugin_unload_service (GOPlugin *plugin, GOPluginService *service, ErrorInfo **ret_error);
+void         go_plugin_load_service (GOPlugin *plugin, GOPluginService *service, GOErrorInfo **ret_error);
+void         go_plugin_unload_service (GOPlugin *plugin, GOPluginService *service, GOErrorInfo **ret_error);
 gboolean     go_plugin_is_loaded (GOPlugin *plugin);
 void         go_plugin_use_ref (GOPlugin *plugin);
 void         go_plugin_use_unref (GOPlugin *plugin);
@@ -59,13 +59,13 @@ void	  go_plugins_unregister_loader (const gchar *id_str);
 GOPlugin *go_plugins_get_plugin_by_id (const gchar *plugin_id);
 GSList	 *go_plugins_get_available_plugins (void);
 GSList	 *go_plugins_get_active_plugins (void);
-void	  go_plugins_rescan (ErrorInfo **ret_error, GSList **ret_new_plugins);
+void	  go_plugins_rescan (GOErrorInfo **ret_error, GSList **ret_new_plugins);
 char 	 *go_plugins_get_plugin_dir (void);
 
 void	  go_plugin_db_mark_plugin_for_deactivation (GOPlugin *plugin, gboolean mark);
 gboolean  go_plugin_db_is_plugin_marked_for_deactivation (GOPlugin *plugin);
-void	  go_plugin_db_activate_plugin_list   (GSList *plugins, ErrorInfo **ret_error);
-void	  go_plugin_db_deactivate_plugin_list (GSList *plugins, ErrorInfo **ret_error);
+void	  go_plugin_db_activate_plugin_list   (GSList *plugins, GOErrorInfo **ret_error);
+void	  go_plugin_db_deactivate_plugin_list (GSList *plugins, GOErrorInfo **ret_error);
 
 G_END_DECLS
 
diff --git a/goffice/app/goffice-app.h b/goffice/app/goffice-app.h
index 1b8930e..428c9be 100644
--- a/goffice/app/goffice-app.h
+++ b/goffice/app/goffice-app.h
@@ -36,7 +36,7 @@ typedef struct _GOPluginService	GOPluginService;
 typedef struct _GOPluginLoader	GOPluginLoader;
 
 /* temporary */
-typedef struct _ErrorInfo		ErrorInfo;
+typedef struct _GOErrorInfo		GOErrorInfo;
 typedef struct _GOFileSaver 		GOFileSaver;
 typedef struct _GOFileOpener		GOFileOpener;
 typedef struct _IOContext		IOContext;
diff --git a/goffice/app/io-context-priv.h b/goffice/app/io-context-priv.h
index b51e4d8..4ebac1b 100644
--- a/goffice/app/io-context-priv.h
+++ b/goffice/app/io-context-priv.h
@@ -47,7 +47,7 @@ struct _IOContext {
 	GObject base;
 
 	GOCmdContext	*impl;
-	ErrorInfo	*info;
+	GOErrorInfo	*info;
 	gboolean	 error_occurred;
 	gboolean	 warning_occurred;
 
diff --git a/goffice/app/io-context.c b/goffice/app/io-context.c
index 8266317..13acf49 100644
--- a/goffice/app/io-context.c
+++ b/goffice/app/io-context.c
@@ -57,7 +57,7 @@ ioc_finalize (GObject *obj)
 	g_return_if_fail (IS_IO_CONTEXT (obj));
 
 	ioc = IO_CONTEXT (obj);
-	error_info_free (ioc->info);
+	go_error_info_free (ioc->info);
 	if (ioc->impl) {
 		go_cmd_context_progress_set (ioc->impl, 0.0);
 		go_cmd_context_progress_message_set (ioc->impl, NULL);
@@ -117,23 +117,23 @@ ioc_error_error (GOCmdContext *cc, GError *err)
 }
 
 static void
-ioc_error_error_info (G_GNUC_UNUSED GOCmdContext *ctxt,
-		      ErrorInfo *error)
+ioc_error_go_error_info_ (G_GNUC_UNUSED GOCmdContext *ctxt,
+		      GOErrorInfo *error)
 {
 	/* TODO what goes here */
-	error_info_print (error);
+	go_error_info_print (error);
 }
 
 void
 gnumeric_io_error_string (IOContext *context, const gchar *str)
 {
-	ErrorInfo *error;
+	GOErrorInfo *error;
 
 	g_return_if_fail (context != NULL);
 	g_return_if_fail (str != NULL);
 
-	error = error_info_new_str (str);
-	gnumeric_io_error_info_set (context, error);
+	error = go_error_info_new_str (str);
+	gnumeric_io_go_error_info_set (context, error);
 }
 
 static void
@@ -142,7 +142,7 @@ io_context_gnm_cmd_context_init (GOCmdContextClass *cc_class)
 	cc_class->get_password	   = ioc_get_password;
 	cc_class->set_sensitive	   = ioc_set_sensitive;
 	cc_class->error.error      = ioc_error_error;
-	cc_class->error.error_info = ioc_error_error_info;
+	cc_class->error.error_info = ioc_error_go_error_info_;
 }
 
 static void
@@ -186,7 +186,7 @@ gnumeric_io_error_unknown (IOContext *context)
 }
 
 void
-gnumeric_io_error_info_set (IOContext *context, ErrorInfo *error)
+gnumeric_io_go_error_info_set (IOContext *context, GOErrorInfo *error)
 {
 	g_return_if_fail (context != NULL);
 	g_return_if_fail (error != NULL);
@@ -198,12 +198,12 @@ gnumeric_io_error_info_set (IOContext *context, ErrorInfo *error)
 }
 
 void
-gnumeric_io_error_push (IOContext *context, ErrorInfo *error)
+gnumeric_io_error_push (IOContext *context, GOErrorInfo *error)
 {
 	g_return_if_fail (context != NULL);
 	g_return_if_fail (error != NULL);
 
-	error_info_add_details (error, context->info);
+	go_error_info_add_details (error, context->info);
 	context->info = error;
 }
 
@@ -231,7 +231,7 @@ gnumeric_io_error_clear (IOContext *context)
 
 	context->error_occurred = FALSE;
 	context->warning_occurred = FALSE;
-	error_info_free (context->info);
+	go_error_info_free (context->info);
 	context->info = NULL;
 }
 
@@ -470,7 +470,7 @@ gnm_io_warning (G_GNUC_UNUSED IOContext *context,
 void
 gnm_io_warning_varargs (IOContext *context, char const *fmt, va_list args)
 {
-	context->info = error_info_new_vprintf (GO_WARNING, fmt, args);
+	context->info = go_error_info_new_vprintf (GO_WARNING, fmt, args);
 	context->warning_occurred = TRUE;
 }
 
diff --git a/goffice/app/io-context.h b/goffice/app/io-context.h
index 6cdfdbe..989bfc1 100644
--- a/goffice/app/io-context.h
+++ b/goffice/app/io-context.h
@@ -18,9 +18,9 @@ IOContext *gnumeric_io_context_new        (GOCmdContext *cc);
 
 void       gnumeric_io_error_unknown      (IOContext *ioc);
 
-void       gnumeric_io_error_info_set     (IOContext *ioc, ErrorInfo *error);
+void       gnumeric_io_go_error_info_set     (IOContext *ioc, GOErrorInfo *error);
 void       gnumeric_io_error_string       (IOContext *ioc, const gchar *str);
-void       gnumeric_io_error_push         (IOContext *ioc, ErrorInfo *error);
+void       gnumeric_io_error_push         (IOContext *ioc, GOErrorInfo *error);
 void       gnumeric_io_error_clear        (IOContext *ioc);
 void       gnumeric_io_error_display      (IOContext *ioc);
 
diff --git a/goffice/component/go-component-factory.c b/goffice/component/go-component-factory.c
index 82b5724..d6e6d5f 100644
--- a/goffice/component/go-component-factory.c
+++ b/goffice/component/go-component-factory.c
@@ -108,7 +108,7 @@ go_mime_type_free (GOMimeType * mime_type)
 
 static void
 go_component_type_service_read_xml (GOPluginService * service, xmlNode * tree,
-				    ErrorInfo ** ret_error)
+				    GOErrorInfo ** ret_error)
 {
 	xmlNode *ptr;
 
@@ -291,7 +291,7 @@ go_component_new_by_mime_type (char const *mime_type)
 	type = g_type_from_name (mtype->component_type_name);
 	if (type == 0)
 	{
-		ErrorInfo *err = NULL;
+		GOErrorInfo *err = NULL;
 		GOPluginService *service =
 			pending_engines
 			? g_hash_table_lookup (pending_engines,
@@ -308,8 +308,8 @@ go_component_new_by_mime_type (char const *mime_type)
 
 		if (err != NULL)
 		{
-			error_info_print (err);
-			error_info_free (err);
+			go_error_info_print (err);
+			go_error_info_free (err);
 		}
 
 		g_return_val_if_fail (type != 0, NULL);
diff --git a/goffice/graph/gog-plot-engine.c b/goffice/graph/gog-plot-engine.c
index 26eb963..eb020b9 100644
--- a/goffice/graph/gog-plot-engine.c
+++ b/goffice/graph/gog-plot-engine.c
@@ -77,7 +77,7 @@ gog_plot_new_by_name (char const *id)
 	GType type = g_type_from_name (id);
 
 	if (type == 0) {
-		ErrorInfo *err = NULL;
+		GOErrorInfo *err = NULL;
 		GOPluginService *service =
 			pending_engines
 			? g_hash_table_lookup (pending_engines, id)
@@ -93,8 +93,8 @@ gog_plot_new_by_name (char const *id)
 		type = g_type_from_name (id);
 
 		if (err != NULL) {
-			error_info_print (err);
-			error_info_free	(err);
+			go_error_info_print (err);
+			go_error_info_free	(err);
 		}
 
 		g_return_val_if_fail (type != 0, NULL);
@@ -230,7 +230,7 @@ pending_plot_types_load (void)
 }
 
 static void
-gog_plot_type_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+gog_plot_type_service_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	char    *path;
 	xmlNode *ptr;
@@ -252,7 +252,7 @@ gog_plot_type_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorIn
 }
 
 static void
-gog_plot_type_service_activate (GOPluginService *service, ErrorInfo **ret_error)
+gog_plot_type_service_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	GSList *l = GOG_PLOT_TYPE_SERVICE (service)->paths;
 	if (l && pending_plot_type_files == NULL)
@@ -267,7 +267,7 @@ gog_plot_type_service_activate (GOPluginService *service, ErrorInfo **ret_error)
 }
 
 static void
-gog_plot_type_service_deactivate (GOPluginService *service, ErrorInfo **ret_error)
+gog_plot_type_service_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	GogPlotTypeService *plot_service = GOG_PLOT_TYPE_SERVICE (service);
 	GSList *l = plot_service->families;
@@ -366,7 +366,7 @@ typedef PluginServiceSimple GogThemeService;
 typedef PluginServiceSimpleClass GogThemeServiceClass;
 
 static void
-gog_theme_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+gog_theme_service_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	GogTheme *theme;
 	xmlNode *ptr;
@@ -446,7 +446,7 @@ gog_trend_line_new_by_name (char const *id)
 	GType type = g_type_from_name (id);
 
 	if (type == 0) {
-		ErrorInfo *err = NULL;
+		GOErrorInfo *err = NULL;
 		GOPluginService *service =
 			pending_trend_lines_engines
 			? g_hash_table_lookup (pending_trend_lines_engines, id)
@@ -462,8 +462,8 @@ gog_trend_line_new_by_name (char const *id)
 		type = g_type_from_name (id);
 
 		if (err != NULL) {
-			error_info_print (err);
-			error_info_free	(err);
+			go_error_info_print (err);
+			go_error_info_free	(err);
 		}
 
 		g_return_val_if_fail (type != 0, NULL);
@@ -551,7 +551,7 @@ pending_trend_line_types_load (void)
 }
 
 static void
-gog_trend_line_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+gog_trend_line_service_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	char    *path;
 	xmlNode *ptr;
@@ -573,7 +573,7 @@ gog_trend_line_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorI
 }
 
 static void
-gog_trend_line_service_activate (GOPluginService *service, ErrorInfo **ret_error)
+gog_trend_line_service_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	GSList *l = GOG_TREND_LINE_SERVICE (service)->paths;
 	if (l && pending_trend_line_type_files == NULL)
@@ -588,7 +588,7 @@ gog_trend_line_service_activate (GOPluginService *service, ErrorInfo **ret_error
 }
 
 static void
-gog_trend_line_service_deactivate (GOPluginService *service, ErrorInfo **ret_error)
+gog_trend_line_service_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	GogTrendLineService *line_service = GOG_TREND_LINE_SERVICE (service);
 	GSList *l = line_service->types;
diff --git a/goffice/utils/datetime.c b/goffice/utils/datetime.c
index ccb7f0a..c110c57 100644
--- a/goffice/utils/datetime.c
+++ b/goffice/utils/datetime.c
@@ -321,7 +321,7 @@ days_between_BASIS_30Ep_360 (GDate const *from, GDate const *to)
 }
 
 /*
- * days_between_basis
+ * go_datetime_days_between_basis
  *
  * @from      : GDate *
  * @to        : GDate *
@@ -335,7 +335,7 @@ days_between_BASIS_30Ep_360 (GDate const *from, GDate const *to)
  */
 
 gint32
-days_between_basis (GDate const *from, GDate const *to, basis_t basis)
+go_datetime_days_between_basis (GDate const *from, GDate const *to, basis_t basis)
 {
 	int sign = 1;
 
@@ -450,7 +450,7 @@ go_coupdays (GDate const *settlement, GDate const *maturity,
 	default:
 		go_coup_cd (&next, settlement, maturity, conv->freq, conv->eom, TRUE);
 		go_coup_cd (&prev, settlement, maturity, conv->freq, conv->eom, FALSE);
-		return days_between_basis (&prev, &next, BASIS_ACT_ACT);
+		return go_datetime_days_between_basis (&prev, &next, BASIS_ACT_ACT);
         }
 }
 
@@ -472,7 +472,7 @@ go_coupdaybs (GDate const *settlement, GDate const *maturity,
 {
 	GDate prev_coupon;
 	go_coup_cd (&prev_coupon, settlement, maturity, conv->freq, conv->eom, FALSE);
-	return days_between_basis (&prev_coupon, settlement, conv->basis);
+	return go_datetime_days_between_basis (&prev_coupon, settlement, conv->basis);
 }
 
 /**
@@ -489,11 +489,11 @@ go_coupdaysnc (GDate const *settlement, GDate const *maturity,
 {
 	GDate next_coupon;
 	go_coup_cd (&next_coupon, settlement, maturity, conv->freq, conv->eom, TRUE);
-	return days_between_basis (settlement, &next_coupon, conv->basis);
+	return go_datetime_days_between_basis (settlement, &next_coupon, conv->basis);
 }
 
 int
-gnm_date_convention_base (GODateConventions const *conv)
+go_date_convention_base (GODateConventions const *conv)
 {
 	g_return_val_if_fail (conv != NULL, 1900);
 	return conv->use_1904 ? 1904 : 1900;
diff --git a/goffice/utils/datetime.h b/goffice/utils/datetime.h
index f3359ea..33c5e92 100644
--- a/goffice/utils/datetime.h
+++ b/goffice/utils/datetime.h
@@ -69,7 +69,7 @@ typedef enum { /* see doc/fn-financial-basis.txt for details */
 	BASIS_MSRB_30_360_SYM = 6         /* Gnumeric extension.  */
 } basis_t;
 
-gint32  days_between_basis (GDate const *from, GDate const *to, basis_t basis);
+gint32  go_datetime_days_between_basis (GDate const *from, GDate const *to, basis_t basis);
 
 typedef struct {
 	int	 freq;
@@ -87,7 +87,7 @@ double go_coupdaybs  (GDate const *settlement, GDate const *maturity,
 double go_coupdaysnc (GDate const *settlement, GDate const *maturity,
 		      GnmCouponConvention const *conv);
 
-int gnm_date_convention_base (GODateConventions const *conv);
+int go_date_convention_base (GODateConventions const *conv);
 
 const GODateConventions *go_date_conv_from_str (const char *s);
 gboolean go_date_conv_equal (const GODateConventions *a, const GODateConventions *b);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/goffice/app/error-info.c b/goffice/app/error-info.c
index df1b54a..bf6a721 100644
--- a/goffice/app/error-info.c
+++ b/goffice/app/error-info.c
@@ -1,5 +1,5 @@
 /*
- * error-info.c: ErrorInfo structure.
+ * error-info.c: GOErrorInfo structure.
  *
  * Author:
  *   Zbigniew Chyla (cyba gnome pl)
@@ -11,32 +11,32 @@
 #include <stdio.h>
 #include <errno.h>
 
-struct _ErrorInfo {
+struct _GOErrorInfo {
 	gchar *msg;
 	GOSeverity severity;
-	GSList *details;          /* list of ErrorInfo */
+	GSList *details;          /* list of GOErrorInfo */
 };
 
-ErrorInfo *
-error_info_new_str (char const *msg)
+GOErrorInfo *
+go_error_info_new_str (char const *msg)
 {
-	ErrorInfo *error = g_new (ErrorInfo, 1);
+	GOErrorInfo *error = g_new (GOErrorInfo, 1);
 	error->msg = g_strdup (msg);
 	error->severity = GO_ERROR;
 	error->details  = NULL;
 	return error;
 }
 
-ErrorInfo *
-error_info_new_vprintf (GOSeverity severity, char const *msg_format,
+GOErrorInfo *
+go_error_info_new_vprintf (GOSeverity severity, char const *msg_format,
 			va_list args)
 {
-	ErrorInfo *error;
+	GOErrorInfo *error;
 
 	g_return_val_if_fail (severity >= GO_WARNING, NULL);
 	g_return_val_if_fail (severity <= GO_ERROR, NULL);
 
-	error = g_new (ErrorInfo, 1);
+	error = g_new (GOErrorInfo, 1);
 	error->msg = g_strdup_vprintf (msg_format, args);
 	error->severity = severity;
 	error->details = NULL;
@@ -44,64 +44,64 @@ error_info_new_vprintf (GOSeverity severity, char const *msg_format,
 }
 
 
-ErrorInfo *
-error_info_new_printf (char const *msg_format, ...)
+GOErrorInfo *
+go_error_info_new_printf (char const *msg_format, ...)
 {
-	ErrorInfo *error;
+	GOErrorInfo *error;
 	va_list args;
 
 	va_start (args, msg_format);
-	error = error_info_new_vprintf (GO_ERROR, msg_format, args);
+	error = go_error_info_new_vprintf (GO_ERROR, msg_format, args);
 	va_end (args);
 
 	return error;
 }
 
-ErrorInfo *
-error_info_new_str_with_details (char const *msg, ErrorInfo *details)
+GOErrorInfo *
+go_error_info_new_str_with_details (char const *msg, GOErrorInfo *details)
 {
-	ErrorInfo *error = error_info_new_str (msg);
-	error_info_add_details (error, details);
+	GOErrorInfo *error = go_error_info_new_str (msg);
+	go_error_info_add_details (error, details);
 	return error;
 }
 
-ErrorInfo *
-error_info_new_str_with_details_list (char const *msg, GSList *details)
+GOErrorInfo *
+go_error_info_new_str_with_details_list (char const *msg, GSList *details)
 {
-	ErrorInfo *error = error_info_new_str (msg);
-	error_info_add_details_list (error, details);
+	GOErrorInfo *error = go_error_info_new_str (msg);
+	go_error_info_add_details_list (error, details);
 	return error;
 }
 
-ErrorInfo *
-error_info_new_from_error_list (GSList *errors)
+GOErrorInfo *
+go_error_info_new_from_error_list (GSList *errors)
 {
-	ErrorInfo *error;
+	GOErrorInfo *error;
 
 	switch (g_slist_length (errors)) {
 	case 0:
 		error = NULL;
 		break;
 	case 1:
-		error = (ErrorInfo *) errors->data;
+		error = (GOErrorInfo *) errors->data;
 		g_slist_free (errors);
 		break;
 	default:
-		error = error_info_new_str_with_details_list (NULL, errors);
+		error = go_error_info_new_str_with_details_list (NULL, errors);
 		break;
 	}
 
 	return error;
 }
 
-ErrorInfo *
-error_info_new_from_errno (void)
+GOErrorInfo *
+go_error_info_new_from_errno (void)
 {
-	return error_info_new_str (g_strerror (errno));
+	return go_error_info_new_str (g_strerror (errno));
 }
 
 void
-error_info_add_details (ErrorInfo *error, ErrorInfo *details)
+go_error_info_add_details (GOErrorInfo *error, GOErrorInfo *details)
 {
 	g_return_if_fail (error != NULL);
 
@@ -115,7 +115,7 @@ error_info_add_details (ErrorInfo *error, ErrorInfo *details)
 }
 
 void
-error_info_add_details_list (ErrorInfo *error, GSList *details)
+go_error_info_add_details_list (GOErrorInfo *error, GSList *details)
 {
 	GSList *new_details_list, *l, *ll;
 
@@ -123,7 +123,7 @@ error_info_add_details_list (ErrorInfo *error, GSList *details)
 
 	new_details_list = NULL;
 	for (l = details; l != NULL; l = l->next) {
-		ErrorInfo *details_error = l->data;
+		GOErrorInfo *details_error = l->data;
 		if (details_error->msg == NULL) {
 			for (ll = details_error->details; ll != NULL; ll = ll->next)
 				new_details_list = g_slist_prepend (new_details_list, l->data);
@@ -137,7 +137,7 @@ error_info_add_details_list (ErrorInfo *error, GSList *details)
 }
 
 void
-error_info_free (ErrorInfo *error)
+go_error_info_free (GOErrorInfo *error)
 {
 	GSList *l;
 
@@ -146,14 +146,14 @@ error_info_free (ErrorInfo *error)
 
 	g_free (error->msg);
 	for (l = error->details; l != NULL; l = l->next)
-		error_info_free ((ErrorInfo *) l->data);
+		go_error_info_free ((GOErrorInfo *) l->data);
 
 	g_slist_free (error->details);
 	g_free(error);
 }
 
 static void
-error_info_print_with_offset (ErrorInfo *error, gint offset)
+go_error_info_print_with_offset (GOErrorInfo *error, gint offset)
 {
 	GSList *l;
 
@@ -168,19 +168,19 @@ error_info_print_with_offset (ErrorInfo *error, gint offset)
 		offset += 2;
 	}
 	for (l = error->details; l != NULL; l = l->next)
-		error_info_print_with_offset ((ErrorInfo *) l->data, offset);
+		go_error_info_print_with_offset ((GOErrorInfo *) l->data, offset);
 }
 
 void
-error_info_print (ErrorInfo *error)
+go_error_info_print (GOErrorInfo *error)
 {
 	g_return_if_fail (error != NULL);
 
-	error_info_print_with_offset (error, 0);
+	go_error_info_print_with_offset (error, 0);
 }
 
 char const *
-error_info_peek_message (ErrorInfo *error)
+go_error_info_peek_message (GOErrorInfo *error)
 {
 	g_return_val_if_fail (error != NULL, NULL);
 
@@ -188,7 +188,7 @@ error_info_peek_message (ErrorInfo *error)
 }
 
 GSList *
-error_info_peek_details (ErrorInfo *error)
+go_error_info_peek_details (GOErrorInfo *error)
 {
 	g_return_val_if_fail (error != NULL, NULL);
 
@@ -196,7 +196,7 @@ error_info_peek_details (ErrorInfo *error)
 }
 
 GOSeverity
-error_info_peek_severity (ErrorInfo *error)
+go_error_info_peek_severity (GOErrorInfo *error)
 {
 	g_return_val_if_fail (error != NULL, GO_ERROR);
 